@@ -29,7 +29,7 @@ local runDebugger = corsixth.require("run_debugger")
 -- and add compatibility code in afterLoad functions
 -- Recommended: Also replace/Update the summary comment
 
-local SAVEGAME_VERSION = 170 -- Version bump for 0.66-beta1
+local SAVEGAME_VERSION = 194 -- CorsixTH 0.68.0 release
 
 class "App"
 
@@ -65,7 +65,9 @@ function App:App()
   }
   self.strings = {}
   self.savegame_version = SAVEGAME_VERSION
-  self.check_for_updates = true
+  self.check_for_updates = TH.GetCompileOptions().update_check
+  self.idle_tick = 0
+  self.window_active_status = false -- whether window is in focus, set after App:init
 end
 
 --! Starts a Lua DBGp client & connects it to a DBGp server.
@@ -84,6 +86,16 @@ function App:setCommandLine(...)
   end
 end
 
+--! Returns the full path of the local path given
+--!param folders (string or table) A string of one segment or an set of many segments of the path
+--!param trailing_slash (boolean) Whether the path needs to end with a local path separator
+--!return fullpath (string) The OS dependent full path
+function App:getFullPath(folders, trailing_slash)
+  if type(folders) ~= "table" then folders = {folders} end
+  local ending = trailing_slash and pathsep or ""
+  return debug.getinfo(1, "S").source:sub(2, -12) .. table.concat(folders, pathsep) .. ending
+end
+
 function App:init()
   -- App initialisation 1st goal: Get the loading screen up
 
@@ -116,8 +128,9 @@ function App:init()
   corsixth.require("filesystem")
   local good_install_folder, error_message = self:checkInstallFolder()
   self.good_install_folder = good_install_folder
-  self.level_dir = debug.getinfo(1, "S").source:sub(2, -12) .. "Levels" .. pathsep
-  self:initUserLevelDir()
+  self.level_dir = self:getFullPath("Levels", true)
+  self.campaign_dir = self:getFullPath("Campaigns", true)
+  self:initUserDirectories()
   self:initSavegameDir()
   self:initScreenshotsDir()
 
@@ -166,6 +179,9 @@ function App:init()
   self:setCaptureMouse()
   self.caption = "CorsixTH"
 
+  -- Create gamelog file if missing
+  self:initGamelogFile()
+
   -- Prereq 2: Load and initialise the graphics subsystem
   corsixth.require("persistance")
   corsixth.require("graphics")
@@ -198,6 +214,28 @@ function App:init()
   -- App initialisation 2nd goal: Load remaining systems and data in an appropriate order
 
   math.randomseed(os.time() + SDL.getTicks())
+  -- The following psuedo-random number generators are based on different
+  -- disritubtion algorithms. For explanations and how to use them see the Wiki
+
+  -- Add math.t_random globally.
+  -- It generates pseudo random triangular distributed numbers in interval (a, b)
+  -- mostly around c between a and b.
+  strict_declare_global "math.t_random"
+  math.t_random = function(a, c, b)
+    assert(a < c, "Left boundary a should be less than center c.")
+    assert(c < b, "Right boundary b should more than center c.")
+    -- normalize c (a -> 0, b -> 1)
+    local range = b - a
+    c = (c - a) / range
+
+    local u = math.random()
+    if u <= c then
+      return a + math.sqrt(c * u) * range
+    else
+      return a + (1 - math.sqrt((1 - c) * (1 - u))) * range
+    end
+  end
+
   -- Add math.n_random globally. It generates pseudo random normally distributed
   -- numbers using the Box-Muller transform.
   strict_declare_global "math.n_random"
@@ -324,7 +362,7 @@ function App:init()
         self.command_line.load = file
       else
         self.command_line.load = "Autosaves" .. pathsep ..
-            FileTreeNode(self.savegame_dir .. "Autosaves"):getMostRecentlyModifiedChildFile(".sav").label
+            FileTreeNode(self.savegame_dir .. "Autosaves"):getMostRecentlyModifiedChildFile(".%.sav$").label
       end
     end
     -- If a savegame was specified, load it
@@ -351,26 +389,52 @@ function App:init()
   return true
 end
 
---! Tries to initialize the user and built in level directories, returns true on
---! success and false on failure.
-function App:initUserLevelDir()
+--! Works out the intended location of the gamelog file.
+--!return full path gamelog should exist at
+function App:getGamelogPath()
+  local config_path = self.command_line["config-file"] or ""
+  config_path = config_path:match("^(.-)[^" .. pathsep .. "]*$")
+  return config_path .. "gamelog.txt"
+end
+
+--! Checks and creates the gamelog file if it does not exist.
+function App:initGamelogFile()
+  local gamelog_path = self:getGamelogPath()
+  local gamelog = io.open(gamelog_path, "r")
+  if gamelog then gamelog:close() return end
+
+  local fi = self:writeToFileOrTmp(gamelog_path)
+  local sysinfo = self:gamelogHeader()
+  fi:write(sysinfo)
+  fi:close()
+end
+
+--! Tries to initialize the user level and campaign directories
+-- TODO: Integrate other directory initialisations into this function
+function App:initUserDirectories()
   local conf_path = self.command_line["config-file"] or "config.txt"
+
+  -- Attempt to set the user's directory choice
+  -- param dir (path) The defined path of the folder by the user
+  -- param label (string) What folder was being set if there was an error
+  -- return The fully qualified path
+  local function setUserDir(dir, label)
+    dir = dir:sub(-1, -1) == pathsep and dir:sub(1, -2) or dir
+    if lfs.attributes(dir, "mode") ~= "directory" and not lfs.mkdir(dir) then
+      -- A failed directory creation does not result in a crash. But the user may lose
+      -- the ability to load/save properly.
+      print("Warning: " .. label .. " directory does not exist and could not be created.")
+    end
+    dir = dir:sub(-1, -1) ~= pathsep and dir .. pathsep or dir
+    return dir
+  end
+
   self.user_level_dir = self.config.levels or
       conf_path:match("^(.-)[^" .. pathsep .. "]*$") .. "Levels"
-
-  if self.user_level_dir:sub(-1, -1) == pathsep then
-    self.user_level_dir = self.user_level_dir:sub(1, -2)
-  end
-  if lfs.attributes(self.user_level_dir, "mode") ~= "directory" then
-    if not lfs.mkdir(self.user_level_dir) then
-      print("Notice: Level directory does not exist and could not be created.")
-      return false
-    end
-  end
-  if self.user_level_dir:sub(-1, -1) ~= pathsep then
-    self.user_level_dir = self.user_level_dir .. pathsep
-  end
-  return true
+  self.user_level_dir = setUserDir(self.user_level_dir, "User Levels")
+  self.user_campaign_dir = self.config.campaigns or
+      conf_path:match("^(.-)[^" .. pathsep .. "]*$") .. "Campaigns"
+  self.user_campaign_dir = setUserDir(self.user_campaign_dir, "User Campaigns")
 end
 
 --! Tries to initialize the savegame directory, returns true on success and
@@ -469,6 +533,8 @@ function App:worldExited()
   self.audio:clearCallbacks()
 end
 
+--! Initialise CorsixTH's main menu screen including relevant windows
+--!param message (string) Something to display to the user
 function App:loadMainMenu(message)
   if self.world then
     self:worldExited()
@@ -494,6 +560,9 @@ function App:loadMainMenu(message)
   if message then
     self.ui:addWindow(UIInformation(self.ui, message))
   end
+
+  -- Reset the idle tick counter
+  self:resetIdle()
 end
 
 --! Sets the mouse capture to the state set within
@@ -526,10 +595,23 @@ function App:loadCampaign(campaign_file)
     return
   end
 
-  self:loadLevel(campaign_info.levels[1], nil, level_info.name,
-    level_info.map_file, level_info.briefing)
-  -- The new world needs to know which campaign to continue on.
-  self.world.campaign_info = campaign_info
+  -- Use localised description and winning text, if available
+  campaign_info.description = self.strings:getLocalisedText(campaign_info.description,
+      campaign_info.description_table)
+  campaign_info.winning_text = self.strings:getLocalisedText(campaign_info.winning_text,
+      campaign_info.winning_text_table)
+
+  if self:loadLevel(campaign_info.levels[1], nil, level_info.name,
+      level_info.map_file, level_info.briefing, nil, _S.errors.load_level_prefix) then
+    -- The new world needs to know which campaign to continue on.
+    self.world.campaign_info = campaign_info
+  end
+
+  -- Play the level advance movie from a position where this campaign will end at 12
+  if campaign_info.movie then
+    local n = math.max(1, 12 - #campaign_info.levels)
+    self.moviePlayer:playAdvanceMovie(n)
+  end
 end
 
 --! Reads the given file name as a Lua chunk from the Campaigns folder in the CorsixTH install directory.
@@ -537,12 +619,10 @@ end
 --!param campaign_file (string) Name of the file to read.
 --!return (table) Definitions found in the campaign file.
 function App:readCampaignFile(campaign_file)
-  local local_path = debug.getinfo(1, "S").source:sub(2, -12)
-  local dir = "Campaigns" .. pathsep
-  local path = local_path .. dir
-  local chunk, err = loadfile_envcall(path .. campaign_file)
+  local path = self:getFullPath({"Campaigns", campaign_file})
+  local chunk, err = loadfile_envcall(path)
   if not chunk then
-    return nil, "Error loading " .. path .. campaign_file .. ":\n" .. tostring(err)
+    return nil, "Error loading " .. path .. ":\n" .. tostring(err)
   else
     local result = {}
     chunk(result)
@@ -577,8 +657,18 @@ function App:readLevelFile(level)
     end
     level_info.deprecated_variable_used = true
   end
-  level_info.briefing = contents:match("%LevelBriefing ?= ?\"(.-)\"")
-  level_info.end_praise = contents:match("%LevelDebriefing ?= ?\"(.-)\"")
+
+  -- Pick a localised set of briefings, if available
+  local lang_code = self.strings:getLangCode()
+  local local_briefing = contents:match("%LevelBriefingTable%." .. lang_code .. " ?= ?\"(.-)\"")
+  local en_briefing = contents:match("%LevelBriefingTable%.en ?= ?\"(.-)\"")
+  local standard_briefing = contents:match("%LevelBriefing ?= ?\"(.-)\"")
+  level_info.briefing = local_briefing or en_briefing or standard_briefing
+
+  local local_end_praise = contents:match("%LevelDebriefingTable%." .. lang_code .. " ?= ?\"(.-)\"")
+  local en_end_praise = contents:match("%LevelDebriefingTable%.en ?= ?\"(.-)\"")
+  local standard_end_praise = contents:match("%LevelDebriefing ?= ?\"(.-)\"")
+  level_info.end_praise = local_end_praise or en_end_praise or standard_end_praise
   return level_info
 end
 
@@ -588,10 +678,13 @@ end
 --!return (string, error) Returns the found absolute path, or nil if not found. Then
 --!       a second variable is returned with an error message.
 function App:getAbsolutePathToLevelFile(level)
-  local path = debug.getinfo(1, "S").source:sub(2, -12)
-  -- First look in Campaigns. If not found there, fall back to Levels.
-  local list_of_possible_paths = { self.user_level_dir, path .. "Campaigns", self.level_dir }
-  for _, parent_path in ipairs(list_of_possible_paths) do
+  local paths_to_search = {
+    self.user_campaign_dir,
+    self.user_level_dir,
+    self.campaign_dir,
+    self.level_dir,
+  }
+  for _, parent_path in ipairs(paths_to_search) do
     local check_path = parent_path .. pathsep .. level
     local file, _ = io.open(check_path, "rb")
     if file then
@@ -602,10 +695,28 @@ function App:getAbsolutePathToLevelFile(level)
   return nil, "Level not found: " .. level
 end
 
--- Loads the specified level. If a string is passed it looks for the file with the same name
+--! Invokes a protected call of App:_loadLevel(...). See that function for more information.
+--! This function should always be called to catch errors and properly pass the
+--! error to the player
+--!param error_prefix (string) (Optional) Prefixes the error relevant to what was loaded
+--! return (boolean) The outcome of the pcall
+function App:loadLevel(level, difficulty, level_name, level_file, level_intro, map_editor, error_prefix)
+  local status, err = pcall(self._loadLevel, self, level, difficulty, level_name,
+      level_file, level_intro, map_editor)
+  if not status then
+    err = error_prefix and error_prefix .. err or "Error while loading level: " .. err
+    print(err)
+    self:loadMainMenu() -- We need to unload all level elements that succeeded
+    self.ui:addWindow(UIInformation(self.ui, { err }))
+  end
+  return status
+end
+
+--! Private Function to load the level. Call via App:loadLevel(...)
+--! Loads the specified level. If a string is passed it looks for the file with the same name
 -- in the "Levels" folder of CorsixTH, if it is a number it tries to load that level from
 -- the original game.
-function App:loadLevel(level, difficulty, level_name, level_file, level_intro, map_editor)
+function App:_loadLevel(level, difficulty, level_name, level_file, level_intro, map_editor)
   if self.world then
     self:worldExited()
   end
@@ -876,13 +987,8 @@ function App:saveConfig()
           -- replace the line, if needed
           handled_ids[identifier] = true
           if value ~= tostring(self.config[identifier]) then
-            local new_value = self.config[identifier]
-            if type(new_value) == "string" then
-              new_value = string.format("[[%s]]", new_value)
-            else
-              new_value = tostring(new_value)
-            end
-            lines[#lines] = string.format("%s = %s", identifier, new_value)
+            lines[#lines] = string.format("%s = %s", identifier,
+                serialize(self.config[identifier], { long_bracket_level_start = 1 } ))
           end
         end
       end
@@ -921,8 +1027,11 @@ function App:writeToFileOrTmp(file, mode)
   if err then
     local tmp_file = os.tmpname()
     f = io.open(tmp_file, mode or "w")
-    self.ui:addWindow(UIInformation(self.ui,
-      { _S.errors.save_to_tmp:format(file, tmp_file, err) }))
+    if self.ui then self.ui:addWindow(UIInformation(self.ui,
+        { _S.errors.save_to_tmp:format(file, tmp_file, err) }))
+    else
+      print("Attempt to write to " .. file .. " failed. File was written instead to temporary location " .. tmp_file .. " because of the error: " .. err)
+    end
   end
   assert(f, "Error: cannot write to filesystem")
   return f
@@ -1134,6 +1243,31 @@ function App:onTick(...)
   return true -- tick events always result in a repaint
 end
 
+--! Function for handling idle time in the main menu, which leads to playing the
+--! demo gameplay trailer if left long enough
+function App:idle()
+  if not self.config.play_demo then return end
+  -- Check if we are in a proper 'idle' state and solely on the main menu
+  if not self.ui:getWindowActiveStatus() or not self.ui:getWindow(UIMainMenu) or
+      self.ui:getWindow(UIUpdate) or self.ui:getWindow(UIConfirmDialog) then
+    self:resetIdle()
+    return
+  end
+  -- Have we been idle enough (~30s)
+  if self.idle_tick > 1000 then
+    -- User is idle, play the demo gameplay movie
+    self.moviePlayer:playDemoMovie()
+    self:resetIdle()
+  else
+    self.idle_tick = self.idle_tick + 1
+  end
+end
+
+-- Reset the idle count
+function App:resetIdle()
+  self.idle_tick = 0
+end
+
 local fps_history = {} -- Used to average FPS over the last thirty frames
 for i = 1, 30 do fps_history[i] = 0 end
 local fps_sum = 0 -- Sum of fps_history array
@@ -1273,8 +1407,10 @@ function App:checkInstallFolder()
       os.getenv("ProgramFiles(x86)"),
       [[C:]], [[D:]], [[E:]], [[F:]], [[G:]], [[H:]] }
     local possible_folders = { "ThemeHospital", "Theme Hospital", "HOSP", "TH97",
-      [[GOG.com\Theme Hospital]], [[GOG Games\Theme Hospital]],
-      [[Origin Games\Theme Hospital\data\Game]] }
+      [[GOG Galaxy\Games\Theme Hospital]], [[GOG.com\Theme Hospital]],
+      [[GOG Games\Theme Hospital]], [[Origin Games\Theme Hospital\data\Game]],
+      [[EA Games\Theme Hospital\data\Game]]
+    }
     for _, dir in pairs(possible_locations) do
       if status then break end
       for _, folder in pairs(possible_folders) do
@@ -1364,6 +1500,27 @@ function App:checkInstallFolder()
   return true, #corrupt ~= 0 and corrupt or nil
 end
 
+function App:findSoundFont()
+  local data_dir = self:getFullPath()
+
+  local possible_locations = {
+    self.config.soundfont or false,
+    data_dir .. "FluidR3_GM.sf2",
+    data_dir .. "FluidR3.sf3",
+    "/usr/share/soundfonts/default.sf2", -- default linux
+    "/usr/share/sounds/sf2/FluidR3_GM.sf2", -- debian based
+    "/usr/share/soundfonts/FluidR3_GM.sf2" -- archlinux and others
+  }
+
+  for _, sf_path in ipairs(possible_locations) do
+    if sf_path and lfs.attributes(sf_path) then
+      return sf_path
+    end
+  end
+
+  return nil
+end
+
 --! Get the directory containing the bitmap files.
 --!return Name of the directory containing the bitmap files, ending with a
 --        directory path separator.
@@ -1437,10 +1594,10 @@ function App:readMapDataFile(filename)
 end
 
 function App:loadLuaFolder(dir, no_results, append_to)
-  local ourpath = debug.getinfo(1, "S").source:sub(2, -8)
-  dir = dir .. pathsep
-  local path = ourpath .. dir
+  if dir:sub(-1) ~= pathsep then dir = dir .. pathsep end
+  local path = self:getFullPath({"Lua", dir}, true)
   local results = no_results and "" or (append_to or {})
+
   for file in lfs.dir(path) do
     if file:match("%.lua$") then
       local status, result = pcall(corsixth.require, dir .. file:sub(1, -5))
@@ -1480,8 +1637,16 @@ end
 -- a specific savegame version is from.
 function App:getVersion(version)
   local ver = version or self.savegame_version
-  if ver > 170 then
+
+  -- Versioning format is major.minor.revision (required) Patch (optional)
+  -- Old versions (<= 0.67) retain existing format
+  -- All patch versions should be retained in this table (due to be replaced, see PR2518)
+  if ver > 194 then
     return "Trunk"
+  elseif ver > 180 then
+    return "v0.68.0"
+  elseif ver > 170 then
+    return "v0.67"
   elseif ver > 156 then
     return "v0.66"
   elseif ver > 138 then
@@ -1587,18 +1752,13 @@ function App:restart()
       self.ui:addWindow(UIInformation(self.ui, { _S.information.cannot_restart }))
       return
     end
-    local status, err = pcall(self.loadLevel, self, level, difficulty, name, file, intro)
-    if not status then
-      err = "Error while loading level: " .. err
-      print(err)
-      self.ui:addWindow(UIInformation(self.ui, { err }))
-    end
+    self:loadLevel(level, difficulty, name, file, intro, nil, _S.errors.load_level_prefix)
   end))
 end
 
 --! Begin the map editor
 function App:mapEdit()
-  self:loadLevel("", nil, nil, nil, nil, true)
+  self:loadLevel("", nil, nil, nil, nil, true, _S.errors.load_map_prefix)
 end
 
 --! Exits the game completely (no confirmation window)
@@ -1679,6 +1839,12 @@ function App:afterLoad()
   self.world:afterLoad(old, new)
 end
 
+--! Runs a comparison between the current (installed) version and the reported
+--! update table hosted by Github. If the update table is newer, it will generate
+--! an update window.
+--! As pre-releases are not announced on the update table, the checker also assumes
+--! that any current version with a patch in its name (Beta, RC, etc) will be older
+--! than the update table's version if their major, minor, and revision components match.
 function App:checkForUpdates()
   -- Only check for updates once per application launch
   if not self.check_for_updates or not self.config.check_for_updates then return end
@@ -1686,11 +1852,7 @@ function App:checkForUpdates()
 
   -- Default language to use for the changelog if no localised version is available
   local default_language = "en"
-  local update_url = 'https://corsixth.com/CorsixTH/check-for-updates'
-  local current_version = string.gsub(self:getVersion(), "v", "") -- drop the 'v'
-
-  -- Only URLs that match this list of trusted domains will be accepted.
-  local trusted_domains = { 'corsixth.com', 'github.com', 'corsixth.github.io' }
+  local current_version = self:getVersion()
 
   -- Only check for updates against released versions
   if current_version == "Trunk" then
@@ -1698,44 +1860,55 @@ function App:checkForUpdates()
     return
   end
 
-  local luasocket, _ = pcall(require, "socket")
-  local luasec, _ = pcall(require, "ssl.https")
-  if not (luasocket and luasec) then
-    print("Cannot check for updates since LuaSocket and/or LuaSec are not available.")
-    return
-  end
-  local http = require("socket.http")
-  local url = require("socket.url")
-
   print("Checking for CorsixTH updates...")
-  local update_body, status, _ = http.request(update_url)
+  local update_body, err = TH.FetchLatestVersionInfo()
 
-  if not update_body or (status ~= 200) then
-    print("Couldn't check for updates. Server returned code: " .. status)
-    print("Check that you have an active internet connection and that CorsixTH is allowed in your firewall.")
+  if not update_body then
+    print("Couldn't check for updates: " .. err)
     return
   end
 
   local update_table = loadstring_envcall(update_body, "@updatechecker") {}
+  update_table.revision = update_table.revision or 0
   local changelog = update_table["changelog_" .. default_language]
-  local new_version = update_table["major"] .. '.' .. update_table["minor"] .. update_table["revision"]
+  local new_version = update_table.major .. '.' .. update_table.minor .. '.' .. update_table.revision
 
-  if (new_version <= current_version) then
+  -- Semantic version comparison of the current and update version numbers
+  -- A return value of true means the current version is newer
+  local function compare_versions()
+    local current_major, current_minor, current_revision, current_patch =
+        string.match(current_version, "(%d+)%.(%d+)%.?(%d*) ?(.*)")
+    current_major, current_minor = tonumber(current_major), tonumber(current_minor)
+    if current_major > update_table.major then return true
+    elseif current_major < update_table.major then return false
+    end
+    if current_minor > update_table.minor then return true
+    elseif current_minor < update_table.minor then return false
+    end
+
+    current_revision = tonumber(current_revision) or 0
+    current_patch = string.len(current_patch) > 0 and current_patch
+    if current_patch then return current_revision > update_table.revision end
+    return current_revision >= update_table.revision
+  end
+  if compare_versions() then
     print("You are running the latest version of CorsixTH.")
     return
   end
 
   -- Check to make sure download URL is trusted
-  local download_url = url.parse(update_table["download_url"])
-  local valid_url = false
-  for _, v in ipairs(trusted_domains) do
-    if download_url.host == v then
-      valid_url = true
+  local download_url = update_table.download_url
+  local trusted_url = false
+  local trusted_prefixes = { 'https://corsixth.com/', 'https://github.com/', 'https://corsixth.github.io/' }
+
+  for _, v in ipairs(trusted_prefixes) do
+    if download_url:sub(1, #v) == v then
+      trusted_url = true
       break
     end
   end
-  if not valid_url then
-    print("Update download url is not on the trusted domains list (" .. update_table["download_url"] .. ")")
+  if not trusted_url then
+    print("Update download url is not on the trusted domains list (" .. download_url .. ")")
     return
   end
 
@@ -1750,7 +1923,7 @@ function App:checkForUpdates()
 
   print("New version found: " .. new_version)
   -- Display the update window
-  self.ui:addWindow(UIUpdate(self.ui, current_version, new_version, changelog, update_table["download_url"]))
+  self.ui:addWindow(UIUpdate(self.ui, current_version, new_version, changelog, download_url))
 end
 
 -- Free up / stop any resources relying on the current video object
@@ -1771,7 +1944,19 @@ function App:isAudioEnabled()
   return TH.GetCompileOptions().audio
 end
 
-function App:getSystemInfo()
+function App:isUpdateCheckDisabledByConfig()
+  return TH.GetCompileOptions().update_check and not self.config.check_for_updates
+end
+
+function App:isUpdateCheckAvailable()
+  return TH.GetCompileOptions().update_check
+end
+
+--! Generate information about user's system and the program
+--!return System and program info as a string
+function App:gamelogHeader()
+  local gen_date = os.date("%Y-%m-%d %H:%M:%S")
+  gen_date = string.format("Gamelog generated on %s\n", gen_date)
   local compile_opts = TH.GetCompileOptions()
   local comp_details = {}
   for key, value in pairs(compile_opts) do
@@ -1779,11 +1964,11 @@ function App:getSystemInfo()
   end
   table.sort(comp_details)
   local compiled = string.format("Compiled with %s\nSDL renderer: %s\n",
-    table.concat(comp_details, ", "), self.video:getRendererDetails())
+      table.concat(comp_details, ", "), self.video:getRendererDetails())
   local running = string.format("%s run with api version: %s, game version: %s, savegame version: %s\n",
-    compile_opts.jit or _VERSION, tostring(corsixth.require("api_version")),
-    self:getVersion(), tostring(SAVEGAME_VERSION))
-  return (compiled .. running)
+      compile_opts.jit or _VERSION, tostring(corsixth.require("api_version")),
+      self:getVersion(), tostring(SAVEGAME_VERSION))
+  return (gen_date .. compiled .. running)
 end
 
 -- Do not remove, for savegame compatibility < r1891
