@@ -100,8 +100,11 @@ function Audio:init()
     - Uses titles from MIDI.TXT if found, else the filename.
   --]]
   local midi_txt -- File name of midi.txt file, if any.
-  local waveform = { MP3=true, OGG=true, WAV=true, AIFF=true, VOC=true, FLAC=true }
-  local instructional = { MID=true, MOD=true, XM=true, XMI=true }
+  local waveform = list_to_set({"OGG", "OPUS", "FLAC", "WV", "WAV", "WAVE",
+      "MPG", "MPEG", "MP3", "MAD", "AIFF", "AIFC", "AIF"})
+  local instructional = list_to_set({"MID", "MIDI", "KAR", "669", "AMF", "AMS", "DBM",
+      "DSM", "FAR", "GDM", "IT", "MED", "MDL", "MOD", "MOL", "MTM", "NST", "OKT", "PTM",
+      "S3M", "STM", "ULT", "UMX", "WOW", "XM", "XMI"})
 
   local _f, _s, _v
   if music_dir then
@@ -111,12 +114,14 @@ function Audio:init()
   end
   for file in _f, _s, _v do
     local info
-    local filename, ext = file:match"^(.+)%.([^.]+)$"
+    local filename, ext = file:match("^(.+)%.([^.]+)$")
     ext = ext and ext:upper()
     if waveform[ext] or instructional[ext] then
       info = musicFileTable(filename)
       -- This title might be replaced later by the midi_txt.
       info.title = filename
+      -- XMI files are supported with our own conversion
+      info.is_xmi = ext == "XMI"
     end
     if instructional[ext] and not music_dir then
        info.filename = table.concat({"Sound", "Midi", file}, pathsep)
@@ -147,15 +152,22 @@ function Audio:init()
     else
       data = assert(self.app.fs:readContents("Sound", "Midi", midi_txt))
     end
-    for file, title in data:gmatch"([^\r\n\26]+).-([^\r\n\26]+)" do
-      local info = musicFileTable(file:match"^(.*)%." or file)
+    local i = 1
+    for file, title in data:gmatch("([^\r\n\26]+).-([^\r\n\26]+)") do
+      local info = musicFileTable(file:match("^(.*)%.") or file)
       if next(info) ~= nil then
         info.title = title
+        info.index = i
+        i = i + 1
       else
         print('Notice: Background track "'.. file ..'" named in list file, '..
               'but it does not exist.')
       end
     end
+    -- Sort by midi.txt order if there is one, or by filename.
+    table.sort(self.background_playlist, function(a,b) return a.index < b.index end)
+  else
+    table.sort(self.background_playlist, function(a,b) return a.title < b.title end)
   end
   if #self.background_playlist == 0 and self.app.good_install_folder then
     print("Notice: Audio system loaded, but found no background tracks")
@@ -164,8 +176,11 @@ function Audio:init()
     self.has_bg_music = true
   end
 
-  local status, err = SDL.audio.init(self.app.config.audio_frequency,
-    self.app.config.audio_channels, self.app.config.audio_buffer_size)
+  local status, err = SDL.audio.init(
+    self.app.config.audio_frequency,
+    self.app.config.audio_channels,
+    self.app.config.audio_buffer_size,
+    self.app:findSoundFont())
   if status then
     -- NB: Playback will not start if play_music is set to false
     self:playRandomBackgroundTrack()
@@ -501,14 +516,8 @@ end
 --! If nil is returned music might either be playing or completely stopped.
 function Audio:pauseBackgroundTrack()
   assert(self.background_music, "Trying to pause music while music is stopped")
-  -- TODO: There is a bug in SDL for Windows that makes all sound, not just music stop
-  -- when pausing. For the time being, stop the music instead to prevent this.
-  self:stopBackgroundTrack()
-  return false
-  -------------------------------------------------
-  -- Real pause logic
-  -------------------------------------------------
-  --[[local status
+
+  local status
   if self.background_paused then
     self.background_paused = nil
     status = SDL.audio.resumeMusic()
@@ -538,7 +547,7 @@ function Audio:pauseBackgroundTrack()
     end
   end
   self:notifyJukebox()
-  return self.background_paused--]]
+  return self.background_paused
 end
 
 --! Stops playing background music for the time being.
@@ -572,7 +581,7 @@ function Audio:playBackgroundTrack(index)
       if data:sub(1, 3) == "RNC" then
         data = assert(rnc.decompress(data))
       end
-      if not info.filename_music then
+      if not info.filename_music or info.is_xmi then
         data = SDL.audio.transcodeXmiToMid(data)
       end
       -- Loading of music files can incur a slight pause, which is why it is
@@ -580,11 +589,24 @@ function Audio:playBackgroundTrack(index)
       -- Someone might want to stop the player from
       -- starting to play once it's loaded though.
       self.load_music = true
-      SDL.audio.loadMusicAsync(data, function(music_data, e)
+      SDL.audio.loadMusicAsync(data, function(music_data, err)
 
         if music_data == nil then
-          error("Could not load music file \'" .. (info.filename_music or info.filename) .. "\'" ..
-              (e and (" (" .. e .. ")" or "")))
+          info.enabled = false
+          local name, msg = (info.filename_music or info.filename)
+          if not self.warned then -- Warn once per session
+            self.app.ui:addWindow(UIInformation(self.app.ui, {_S.errors.music}))
+          end
+          self.warned = true
+          if err == "No SoundFonts have been requested" then
+            msg = "Required soundfont is not found, please download one. A suitable soundfont is linked from the CorsixTH wiki."
+          elseif err == "XMP: Unrecognized file format" or err == "ModPlug_Load failed" then
+            msg = "Music format not supported for file " .. name
+          else
+            msg = "Could not load music file " .. name .. ". Error: " .. err
+          end
+          if self.app.world then self.app.world:gameLog(msg) end
+          if not self.app.world or not self.app.config.debug then print(msg) end
         else
           info.music = music_data
           -- Do we still want it to play?
