@@ -100,8 +100,8 @@ function CallsDispatcher:callForRepair(object, urgent, manual, lock_room)
   lock_room = manual or lock_room
 
   local call = {
-    verification = --[[persistable:call_dispatcher_repair_verification]] function(staff) return false end,
-    priority = --[[persistable:call_dispatcher_repair_priority]] function(staff) return 1 end,
+    verification = --[[persistable:call_dispatcher_repair_verification]] function() return false end,
+    priority = --[[persistable:call_dispatcher_repair_priority]] function() return 1 end,
     execute = --[[persistable:call_dispatcher_repair_execute]] function(staff) return CallsDispatcher.sendStaffToRepair(object, staff) end,
     object = object,
     key = "repair",
@@ -113,18 +113,12 @@ function CallsDispatcher:callForRepair(object, urgent, manual, lock_room)
   }
 
   object:setRepairingMode(lock_room and true or false)
-  local message
-  local ui = object.world.ui
-  if object.world:getLocalPlayerHospital():countStaffOfCategory("Handyman", 1) == 0 then
-    -- Advise about hiring Handyman
-    message = _A.warnings.machinery_damaged2
-  end
 
   if not manual and urgent then
-    message = _A.warnings.machines_falling_apart
-  end
-  if message then
-    ui.adviser:say(message)
+    object.hospital:giveAdvice({_A.warnings.machines_falling_apart})
+  elseif object.hospital:countStaffOfCategory("Handyman", 1) == 0 then
+    -- Advise about hiring Handyman
+    object.hospital:giveAdvice({_A.warnings.machinery_damaged2})
   end
 
   if not self.call_queue[object] then
@@ -136,9 +130,9 @@ end
 
 function CallsDispatcher:callForWatering(plant)
   local call = {
-    verification = --[[persistable:call_dispatcher_watering_verification]]function(staff)
+    verification = --[[persistable:call_dispatcher_watering_verification]]function()
       return false end,
-    priority = --[[persistable:call_dispatcher_watering_priority]] function(staff)
+    priority = --[[persistable:call_dispatcher_watering_priority]] function()
       return 1 end,
     execute = --[[persistable:call_dispatcher_watering_execute]] function(staff) return CallsDispatcher.sendStaffToWatering(plant, staff) end,
     object = plant,
@@ -509,7 +503,7 @@ function CallsDispatcher.getPriorityForRoom(room, attribute, staff)
     score = score + distance
   end
 
-  -- More people on the queue has to be served eariler
+  -- More people on the queue has to be served earlier
   if room.door.queue then
     score = score - room.door.queue:reportedSize() * 5 -- 5 is just a weighting scale
     if room.door.queue:hasEmergencyPatient() then
@@ -518,7 +512,7 @@ function CallsDispatcher.getPriorityForRoom(room, attribute, staff)
   end
 
   -- Prefer the tirer staff (such that less chance to have "resting synchronization issue")
-  score = score - staff.attributes["fatigue"] * 40 -- 40 is just a weighting scale
+  score = score - staff:getAttribute("fatigue") * 40 -- 40 is just a weighting scale
 
   -- TODO: Assign doctor with higher ability
 
@@ -542,7 +536,7 @@ function CallsDispatcher.sendStaffToRoom(room, staff)
   staff:setDynamicInfoText(_S.dynamic_info.staff.actions.heading_for:format(room.room_info.name))
 end
 
-function CallsDispatcher.staffActionInterruptHandler(action, humanoid, high_priority)
+function CallsDispatcher.staffActionInterruptHandler(action, humanoid)
   if action.call.assigned == humanoid then
     action.call.assigned = nil
     humanoid.on_call = nil
