@@ -107,6 +107,7 @@ local config_defaults = {
   music_volume = 0.5,
   prevent_edge_scrolling = false,
   capture_mouse = true,
+  right_mouse_scrolling = false,
   adviser_disabled = false,
   scrolling_momentum = 0.8,
   twentyfour_hour_clock = true,
@@ -145,6 +146,7 @@ local config_defaults = {
   allow_blocking_off_areas = false,
   direct_zoom = nil,
   new_machine_extra_info = true,
+  debug_falling = false,
   player_name = [[]],
 }
 
@@ -233,6 +235,7 @@ local string_01 = [=[
 --  Russian               / ru / rus
 --  Spanish               / es / spa
 --  Swedish               / sv / swe
+--  Ukrainian             / uk / ukr
 --]=] .. '\n' ..
 'language = [['.. config_values.language ..']]' .. '\n' .. [=[
 
@@ -284,6 +287,14 @@ local string_01 = [=[
 --]=] .. '\n' ..
 'capture_mouse = ' .. tostring(config_values.capture_mouse) .. '\n' .. [=[
 
+-------------------------------------------------------------------------------
+-- Right Mouse Scrolling: By default, it is disabled (right_mouse_scrolling = false).
+-- This means that the default scrolling method is pressing the middle mouse button.
+-- Please note this an Experimental Feature and may interfere with other right mouse
+-- operations. Report bugs for this on Github Issue 2469.
+--]=] .. '\n' ..
+'right_mouse_scrolling = ' .. tostring(config_values.right_mouse_scrolling) .. '\n' .. [=[
+
 -------------------------------------------------------------------------------
 -- Adviser on/off: If you set this to true the adviser will no longer
 -- pop up.
@@ -431,6 +442,7 @@ campaigns = nil -- [[X:\ThemeHospital\Campaigns]]
 -------------------------------------------------------------------------------
 -- Use new graphics. Whether to use the original graphics from Theme Hospital
 -- or use new graphics created by the CorsixTH project.
+-- Developer use only, otherwise the game will very likely crash in normal use
 use_new_graphics = false
 
 -------------------------------------------------------------------------------
@@ -481,9 +493,16 @@ audio_music = nil -- [[X:\ThemeHospital\Music]]
 --]=] .. '\n' ..
 'debug = ' .. tostring(config_values.debug) .. '\n' .. [=[
 
---Optional settings for CorsixTH's Lua DBGp client. Default settings are
--- nil values, platform & workingdir will be autodected if nil.
---https://wiki.eclipse.org/LDT/User_Area/User_Guides/User_Guide_1.2#Attach_session
+-- Experimental setting for falling patients. (debug only!)
+-- CorsixTH does not yet have reliable handling for falling actions and enabling it
+-- could cause dropped action queues or undesired bugs. You should leave this setting
+-- off unless you're developing with it
+--]=] .. '\n' ..
+'debug_falling = ' .. tostring(config_values.debug_falling) .. '\n' .. [=[
+
+-- Optional settings for CorsixTH's Lua DBGp client. Default settings are
+-- nil values, platform & working dir will be autodetected if nil.
+-- https://wiki.eclipse.org/LDT/User_Area/User_Guides/User_Guide_1.2#Attach_session
 --]=] .. '\n' ..
 'idehost = ' .. tostring(config_values.DBGp_client_idehost) .. '\n' ..
 'ideport = ' .. tostring(config_values.DBGp_client_ideport) .. '\n' ..
