@@ -171,7 +171,7 @@ falling_anim("Standard Female Patient",   3116)
 --  | Name                                 |Anim| Notes
 ----+--------------------------------+-----+-----+-----+-----+------+------+
 on_ground_anim("Standard Male Patient",     1258)
-on_ground_anim("Standard Female Patient",   3116)
+on_ground_anim("Standard Female Patient",   1764)
 
 --  | Get_up Animations                   |
 --  | Name                                 |Anim| Notes
@@ -353,7 +353,7 @@ end
 -- Function which is called when the user clicks on the `Humanoid`.
 --!param ui (GameUI) The UI which the user in question is using.
 --!param button (string) One of: "left", "middle", "right".
-function Humanoid:onClick(ui, button) -- luacheck: ignore 212 keep args from parent class
+function Humanoid:onClick(ui, button)
   if TheApp.config.debug then
     self:dump()
   end
@@ -629,7 +629,7 @@ function Humanoid:_handleEmptyActionQueue()
   self.world:gameLog("Last action: " .. self.previous_action.name)
   self.world:gameLog(debug.traceback())
 
-  ui:addWindow(UIConfirmDialog(ui, true, {_S.errors.dialog_empty_queue},
+  ui:addWindow(UIConfirmDialog(ui, true, _S.errors.dialog_empty_queue,
     --[[persistable:humanoid_leave_hospital]] function()
       self.world:gameLog("The humanoid was told to leave the hospital...")
       if class.is(self, Staff) then
@@ -690,10 +690,10 @@ end
 
 -- Stub functions for handling fatigue. These are overridden by the staff subclass,
 -- but also defined here, so we can just call it on any humanoid
-function Humanoid:tire(amount) -- luacheck: ignore 212 keep args for child class
+function Humanoid:tire(amount)
 end
 
-function Humanoid:wake(amount) -- luacheck: ignore 212 keep args for child class
+function Humanoid:wake(amount)
 end
 
 function Humanoid:updateSpeed()
@@ -737,10 +737,18 @@ end
 --!param amount (number) This amount is added to the existing value for the attribute,
 --  and is then capped to be between 0 and 1.
 function Humanoid:changeAttribute(attribute, amount)
-  -- Receptionist is always 100% happy
-  if self.humanoid_class and self.humanoid_class == "Receptionist" and attribute == "happiness" then
-    self.attributes[attribute] = 1
-    return true
+  -- Handle some happiness special cases
+  if attribute == "happiness" and self.humanoid_class then
+    local max_salary = self.world.map.level_config.payroll.MaxSalary
+    if self.humanoid_class == "Receptionist" then
+      -- A receptionist is never unhappy
+      self.attributes[attribute] = 1
+      return true
+    elseif self.profile and self.profile.wage >= max_salary then
+      -- A maximum salaried staff member is never unhappy
+      self.attributes[attribute] = 1
+      return true
+    end
   end
 
   if self.attributes[attribute] then
@@ -762,7 +770,7 @@ function Humanoid:tickDay()
   end
 
   local temperature = self.world.map.th:getCellTemperature(self.tile_x, self.tile_y)
-  self.attributes.warmth = self.attributes.warmth * 0.75 + temperature * 0.25
+  self.attributes.warmth = self:getAttribute("warmth") * 0.75 + temperature * 0.25
 
   -- If it is too hot or too cold, start to decrease happiness and
   -- show the corresponding icon. Otherwise we could get happier instead.
@@ -770,15 +778,16 @@ function Humanoid:tickDay()
   local max_comfort_temp = 0.36 -- 18 degrees Celsius.
   local decrease_factor = 0.10
   local increase_happiness = 0.005
+  local warmth = self:getAttribute("warmth")
 
-  if self.attributes["warmth"] and self.hospital then
+  if warmth and self.hospital then
     -- Cold: less than comfortable.
-    if self.attributes["warmth"] < min_comfort_temp then
-      self:changeAttribute("happiness", -decrease_factor * (min_comfort_temp - self.attributes["warmth"]))
+    if warmth < min_comfort_temp then
+      self:changeAttribute("happiness", -decrease_factor * (min_comfort_temp - warmth))
       self:setMood("cold", "activate")
     -- Hot: More than comfortable.
-    elseif self.attributes["warmth"] > max_comfort_temp then
-      self:changeAttribute("happiness", -decrease_factor * (self.attributes["warmth"] - max_comfort_temp))
+    elseif warmth > max_comfort_temp then
+      self:changeAttribute("happiness", -decrease_factor * (warmth - max_comfort_temp))
       self:setMood("hot", "activate")
     -- Ideal: Not too cold or too warm.
     else
@@ -926,13 +935,13 @@ function Humanoid:tostring()
   local result = string.format("%s - class: %s", full_name, class)
 
   result = result .. string.format("\nWarmth: %.3f   Happiness: %.3f   Fatigue: %.3f  Thirst: %.3f  Toilet_Need: %.3f   Health: %.3f   Service Quality: %.3f",
-    self.attributes["warmth"] or 0,
-    self.attributes["happiness"] or 0,
-    self.attributes["fatigue"] or 0,
-    self.attributes["thirst"] or 0,
-    self.attributes["toilet_need"] or 0,
-    self.attributes["health"] or 0,
-    self.attributes["fatigue"] and self:getServiceQuality() or 0)
+    self:getAttribute("warmth"),
+    self:getAttribute("happiness"),
+    self:getAttribute("fatigue"),
+    self:getAttribute("thirst"),
+    self:getAttribute("toilet_need"),
+    self:getAttribute("health"),
+    self.getServiceQuality and self:getServiceQuality() or 0)
 
   result = result .. "\nActions: ["
   for i = 1, #self.action_queue do
@@ -984,3 +993,11 @@ function Humanoid:unexpectFromRoom(dest_room)
     end
   end
  end
+
+-- Get attribute value
+--!param attribute (string)
+--!param default_value (float) Number to return if none found. If neither are present, 0 is returned
+--!return (float)
+function Humanoid:getAttribute(attribute, default_value)
+  return self.attributes[attribute] or default_value or 0
+end
