@@ -72,6 +72,14 @@ function Patient:onClick(ui, button)
         ui:addWindow(UIPatient(ui, self))
       end
     end
+  elseif TheApp.config.debug_falling and button == "right" then
+    -- Attempt to push patient over
+    -- Currently debug-only, enable in config file for testing.
+    -- Once confirmed working, the debugging flag can be removed.
+    if not self.world:isPaused() and not (self.cured or self.dead or self.going_home)
+         and math.random(1, 2) == 2 then
+      self:falling(true)
+    end
   elseif self.user_of then
     -- The object we're using is made invisible, as the animation contains both
     -- the humanoid and the object. Hence send the click onto the object.
@@ -178,7 +186,7 @@ function Patient:completeDiagnosticStep(room)
   -- Did the staff member manage to leave the room before the patient had
   -- a chance to get diagnosed? Then use a default middle value.
   if room.staff_member then
-    local fatigue = room.staff_member.attributes["fatigue"] or 0
+    local fatigue = room.staff_member:getAttribute("fatigue")
 
     -- Bonus: based on skill and attn to detail (with some randomness).
     -- additional bonus if the staff member is highly skilled / consultant
@@ -246,7 +254,7 @@ function Patient:getPriceDistortion(casebook)
   local reputation = casebook.reputation or self.hospital.reputation
   local effectiveness = casebook.cure_effectiveness
 
-  local weighted_happiness = happiness_weight * self.attributes.happiness
+  local weighted_happiness = happiness_weight * self:getAttribute("happiness")
   local weighted_reputation = reputation_weight * (reputation / 1000)
   local weighted_effectiveness = effectiveness_weight * (effectiveness / 100)
 
@@ -341,10 +349,10 @@ function Patient:die()
   self:setDynamicInfoText(_S.dynamic_info.patient.actions.dying)
 end
 
--- Actions we can interrupt for in the canPeeOrPuke function
+-- Actions we can interrupt for in the canPeePukeOrFall function
 local good_actions = {walk=true, idle=true, seek_room=true, queue=true}
 
-function Patient:canPeeOrPuke(current)
+function Patient:canPeePukeOrFall(current)
   if not good_actions[current.name] then return false end
   if self.going_home then return false end
 
@@ -356,30 +364,25 @@ function Patient:canPeeOrPuke(current)
   return parcel ~= 0 and th:getPlotOwner(parcel) == self.hospital:getPlayerIndex()
 end
 
---! Animations for when there is an earth quake
-function Patient:falling()
+--! Falling animations for when there is an earth quake or the player is being very mean
+--!param player_init (bool) if true, player triggered the fall
+function Patient:falling(player_init)
   local current = self:getCurrentAction()
   current.keep_reserved = true
-  if self.falling_anim and self:canPeeOrPuke(current) and self.has_fallen == 1 then
-    self:setNextAction(FallingAction(), 0)
+  if self.falling_anim and self:canPeePukeOrFall(current) and self.has_fallen == 1 then
     self.has_fallen = 2
-    if self.has_fallen == 2 then
-      self:setNextAction(OnGroundAction())
-      self.on_ground = true
+    self:queueAction(FallingAction(), 1)
+    self:queueAction(OnGroundAction(), 2)
+    self:queueAction(GetUpAction(), 3)
+    -- show the patient is annoyed, if possbile
+    if math.random(1, 5) == 3 and self.shake_fist_anim then
+      self:queueAction(ShakeFistAction(), 4)
+      self:interruptAndRequeueAction(current, 5)
+    else
+      self:interruptAndRequeueAction(current, 4)
     end
-    if self.on_ground then
-      self:setNextAction(GetUpAction())
-    end
-    -- TODO: falls are broken, the will change once implemented
-    self:interruptAndRequeueAction(current, 2)
-    self.on_ground = false
-    if math.random(1, 5) == 3 then
-      self:shakeFist()
-    end
-    self:fallingAnnounce()
+    if player_init then self:fallingAnnounce() end
     self:changeAttribute("happiness", -0.05) -- falling makes you very unhappy
-  else
-    return
   end
 end
 
@@ -395,17 +398,10 @@ function Patient:fallingAnnounce()
   self.hospital:giveAdvice(msg)
 end
 
---! Perform 'shake fist' action.
-function Patient:shakeFist()
-  if self.shake_fist_anim then
-    self:queueAction(ShakeFistAction(), 1)
-  end
-end
-
 function Patient:vomit()
   local current = self:getCurrentAction()
   --Only vomit under these conditions. Maybe I should add a vomit for patients in queues too?
-  if self:canPeeOrPuke(current) and self.has_vomitted == 0 then
+  if self:canPeePukeOrFall(current) and self.has_vomitted == 0 then
     self:queueAction(VomitAction(), 1)
     self:interruptAndRequeueAction(current, 2)
     self.has_vomitted = self.has_vomitted + 1
@@ -418,7 +414,7 @@ end
 function Patient:pee()
   local current = self:getCurrentAction()
   --Only pee under these conditions. As with vomit, should they also pee if in a queue?
-  if self:canPeeOrPuke(current) then
+  if self:canPeePukeOrFall(current) then
     self:queueAction(PeeAction(), 1)
     self:interruptAndRequeueAction(current, 2)
     self:setMood("poo", "deactivate")
@@ -574,7 +570,7 @@ function Patient:tickDay()
   end
 
   -- if patients are getting unhappy, then maybe we should see this!
-  if self.attributes["happiness"] < 0.3 then
+  if self:getAttribute("happiness") < 0.3 then
     self:setMood("sad7", "activate")
   else
     self:setMood("sad7", "deactivate")
@@ -592,42 +588,43 @@ function Patient:tickDay()
   -- Note: This behaviour intentionally differs from Theme Hospital where being close to
   -- death does not impact happiness.
   -- TODO clean up this block, nonmagical numbers
-  if self.attributes["health"] >= 0.18 and self.attributes["health"] < 0.22 then
+  local health = self:getAttribute("health")
+  if health >= 0.18 and health < 0.22 then
     self:setMood("sad2", "activate")
     self:changeAttribute("happiness", -0.0002) -- waiting too long will make you sad
     -- There is a 1/3 chance that the patient will get fed up and leave.
     -- This is potentially run 10 ((0.22-0.18)/0.004) times, hence the 1/30 chance.
-    -- If patient is already in the cure rodwom, let the treatment happen.
+    -- If patient is already in the cure room, let the treatment happen.
     if not self:_checkIfCureRoom(self:getRoom()) and math.random(1,30) == 1 then
       self:setDynamicInfoText(_S.dynamic_info.patient.actions.fed_up)
       self:setMood("sad2", "deactivate")
       self:goHome("kicked")
     end
-  elseif self.attributes["health"] >= 0.14 and self.attributes["health"] < 0.18 then
+  elseif health >= 0.14 and health < 0.18 then
     self:setMood("sad2", "deactivate")
     self:setMood("sad3", "activate")
   -- now wishes they had gone to that other hospital
-  elseif self.attributes["health"] >= 0.10 and self.attributes["health"] < 0.14 then
+  elseif health >= 0.10 and health < 0.14 then
     self:setMood("sad3", "deactivate")
     self:setMood("sad4", "activate")
   -- starts to take a turn for the worse and is slipping away
-  elseif self.attributes["health"] >= 0.06 and self.attributes["health"] < 0.10 then
+  elseif health >= 0.06 and health < 0.10 then
     self:setMood("sad4", "deactivate")
     self:setMood("sad5", "activate")
   -- fading fast
-  elseif self.attributes["health"] >= 0.01 and self.attributes["health"] < 0.06 then
+  elseif health >= 0.01 and health < 0.06 then
     self:setMood("sad5", "deactivate")
     self:setMood("sad6", "activate")
   -- it's not looking good
-  elseif self.attributes["health"] > 0.00 and self.attributes["health"] < 0.01 then
+  elseif health > 0.00 and health < 0.01 then
     self.attributes["health"] = 0.0
   -- is there time to say a prayer
-  elseif self.attributes["health"] == 0.0 then
+  elseif health == 0.0 then
     if not self:getRoom() and not self:getCurrentAction().is_leaving then
       self:setMood("sad6", "deactivate")
       self:die()
     end
-    -- Patient died, will die when the leave the room, will be cured, or is leaving
+    -- Patient died, will die when they leave the room, will be cured, or is leaving
     -- the hospital. Regardless we do not need to adjust any other attribute
     return
   end
@@ -644,14 +641,14 @@ function Patient:tickDay()
   if not self.health_history then
     -- First day, initialize health history.
     self.health_history = {}
-    self.health_history[1] = self.attributes["health"]
+    self.health_history[1] = self:getAttribute("health")
     self.health_history["last"] = 1
     self.health_history["size"] = 20
   else
     -- Update the health history, wrapping around the array.
     local last = self.health_history["last"] + 1
     if last > self.health_history["size"] then last = 1 end
-    self.health_history[last] = self.attributes["health"]
+    self.health_history[last] = self:getAttribute("health")
     self.health_history["last"] = last
   end
 
@@ -661,7 +658,7 @@ function Patient:tickDay()
     --Only a patient with a health value of less than 0.8 can be the initial vomiter, however :)
     local initialVomitMult = 0.002 --The initial chance of vomiting.
     local proximityVomitMult = 1.5 --The multiplier used when in proximity to vomit.
-    local nausea = (1.0 - self.attributes["health"]) * initialVomitMult
+    local nausea = (1.0 - self:getAttribute("health")) * initialVomitMult
     local foundVomit = {}
     local numVomit = 0
 
@@ -694,7 +691,7 @@ function Patient:tickDay()
     -- As we don't yet have rats, ratholes and dead rats the chances of vomitting are slim
     -- as a temp fix for this I have added 0.5 to the < nausea equation,
     -- this may want adjusting or removing when the other factors are in the game MarkL
-    if self.attributes["health"] <= 0.8 or numVomit > 0 or self.attributes["happiness"] < 0.6 then
+    if self:getAttribute("health") <= 0.8 or numVomit > 0 or self:getAttribute("happiness") < 0.6 then
       nausea = nausea * ((numVomit+1) * proximityVomitMult)
       if math.random() < nausea + 0.5 then
         self:vomit()
@@ -721,15 +718,15 @@ function Patient:tickDay()
   end
 
   -- Each tick both thirst, warmth and toilet_need changes and health decreases.
-  self:changeAttribute("thirst", self.attributes["warmth"]*0.02+0.004*math.random() + 0.004)
+  self:changeAttribute("thirst", self:getAttribute("warmth") * 0.02 + 0.004 * math.random() + 0.004)
   self:changeAttribute("health", - 0.004)
   if self.disease.more_loo_use then
-    self:changeAttribute("toilet_need", 0.018*math.random() + 0.008)
+    self:changeAttribute("toilet_need", 0.018 * math.random() + 0.008)
   else
-    self:changeAttribute("toilet_need", 0.006*math.random() + 0.002)
+    self:changeAttribute("toilet_need", 0.006 * math.random() + 0.002)
   end
   -- Maybe it's time to visit the loo?
-  if self.attributes["toilet_need"] and self.attributes["toilet_need"] > 0.75 then
+  if self:getAttribute("toilet_need") > 0.75 then
     if self.pee_anim and not self:getCurrentAction().is_leaving and
         not self:getCurrentAction().is_entering and not self.in_room then
       if math.random(1, 10) < 5 then
@@ -758,7 +755,7 @@ function Patient:tickDay()
   end
 
   -- If thirsty enough a soda would be nice
-  if self.attributes["thirst"] and self.attributes["thirst"] > 0.7 then
+  if self:getAttribute("thirst") > 0.7 then
     self:changeAttribute("happiness", -0.002)
     self:setMood("thirsty", "activate")
     -- If there's already an action to buy a drink in the action queue, or
@@ -883,6 +880,7 @@ function Patient:setTile(x, y)
     if self.litter_countdown == 0 then
       if x and not self:getRoom() and not self.world:getObjects(x, y) and
           self.world.map.th:getCellFlags(x, y).buildable and
+          self.hospital:isInHospital(x, y) and
           (not self.world:findObjectNear(self, "bin", 8) or math.random() < 0.05) then
         -- Drop some litter!
         local trash = math.random(1, 4)
@@ -981,15 +979,13 @@ function Patient:updateDynamicInfo()
   end
   -- Set the centre line of dynamic info based on contagiousness, if appropriate
   local epidemic = self.hospital and self.hospital.epidemic
-  if epidemic and epidemic.coverup_in_progress then
-    if self.infected and not self.vaccinated then
-      self:setDynamicInfo('text',
-        {action_string, _S.dynamic_info.patient.actions.epidemic_contagious, info})
-    elseif self.vaccinated then
+  if epidemic and self.infected and epidemic.coverup_in_progress then
+    if self.vaccinated then
       self:setDynamicInfo('text',
         {action_string, _S.dynamic_info.patient.actions.epidemic_vaccinated, info})
     else
-      self:setDynamicInfo('text', {action_string, "", info})
+      self:setDynamicInfo('text',
+        {action_string, _S.dynamic_info.patient.actions.epidemic_contagious, info})
     end
   else
     self:setDynamicInfo('text', {action_string, "", info})
@@ -1034,8 +1030,7 @@ function Patient:updateMessage(choice)
         -- no requirements missing
         enabled = false
       end
-    else -- if choice == "guess_cure" then
-      -- TODO: implement
+    -- TODO: implement choice == "guess_cure"
     end
 
     for _, c in ipairs(self.message.choices) do
@@ -1114,15 +1109,37 @@ function Patient:afterLoad(old, new)
       self.th:setPatientEffect(AnimationEffect.None)
     end
   end
+  -- fix walks into room - regression in #2086
+  if old < 177 then
+    for i, action in ipairs(self.action_queue) do
+      if action.name == "walk" and action.is_entering then
+        action.saved_must_happen = false
+        -- if its not the currently executing action
+        -- we should set must_happen to false
+        if i > 1 then
+          action.must_happen = false
+        end
+      end
+    end
+  end
+  if old < 190 then
+    if self.humanoid_class == "Standard Female Patient" then
+      self.on_ground_anim = 1764
+    end
+  end
   self:updateDynamicInfo()
   Humanoid.afterLoad(self, old, new)
 end
 
 function Patient:isMalePatient()
-  if string.find(self.humanoid_class,"Female") then return false
-  elseif string.find(self.humanoid_class,"Male") then return true
+  if string.find(self.humanoid_class, "Female") then return false
+  elseif string.find(self.humanoid_class, "Male") then return true
   else
-    local male_patient_classes = {["Chewbacca Patient"] = true,["Elvis Patient"] = true,["Invisible Patient"] = true}
+    local male_patient_classes = {
+      ["Chewbacca Patient"] = true,
+      ["Elvis Patient"] = true,
+      ["Invisible Patient"] = true
+    }
     return male_patient_classes[self.humanoid_class] ~= nil
   end
 end
@@ -1146,7 +1163,9 @@ function Patient:interruptAndRequeueAction(current_action, queue_pos, meander_be
   elseif current_action.name == "walk" then
     requeue_action = WalkAction(current_action.x, current_action.y)
     requeue_action:setMustHappen(current_action.must_happen)
-
+    if current_action.saved_must_happen ~= nil then
+      requeue_action.must_happen = current_action.saved_must_happen
+    end
     -- need to copy the reserve_on_resume, otherwise the new queued action will not
     -- unreserve on interrupt
     requeue_action.reserve_on_resume = current_action.reserve_on_resume
