@@ -43,29 +43,28 @@ function Staff:tickDay()
   if not Humanoid.tickDay(self) then
     return false
   end
+  if self.humanoid_class == "Receptionist" then return true end
   -- Pay too low  --> unhappy
   -- Pay too high -->   happy
   local fair_wage = self.profile:getFairWage()
   local wage = self.profile.wage
   self:changeAttribute("happiness", 0.05 * (wage - fair_wage) / (fair_wage ~= 0 and fair_wage or 1))
+
   -- if you overwork your Dr's then there is a chance that they can go crazy
   -- when this happens, find him and get him to rest straight away
-  if self.attributes["fatigue"] then
-    if self.attributes["fatigue"] < 0.7 then
-      if self:isResting() then
-        self:setMood("tired", "deactivate")
-        self:changeAttribute("happiness", 0.006)
-      end
-    end
-  -- Working when you should be taking a break will make you unhappy
-    if self.attributes["fatigue"] >= self.hospital.policies["goto_staffroom"] then
-      self:changeAttribute("happiness", -0.02)
-    end
-  -- You will also start to become unhappy as you become tired
-    if self.attributes["fatigue"] >= 0.5 then
-      self:changeAttribute("happiness", -0.01)
-    end
+  if not self:isVeryTired() and self:isResting() then
+    self:setMood("tired", "deactivate")
+    self:changeAttribute("happiness", 0.006)
   end
+  -- Working when you should be taking a break will make you unhappy
+  if self:getAttribute("fatigue") >= self.hospital.policies["goto_staffroom"] then
+    self:changeAttribute("happiness", -0.02)
+  end
+  -- You will also start to become unhappy as you become tired
+  if self:getAttribute("fatigue") >= 0.5 then
+    self:changeAttribute("happiness", -0.01)
+  end
+
   -- It is nice to see plants, but dead plants make you unhappy
   self.world:findObjectNear(self, "plant", 2, function(x, y)
     local plant = self.world:getObject(x, y, "plant")
@@ -103,20 +102,7 @@ function Staff:tickDay()
 
   local room = self:getRoom()
   if room then
-    -- It always makes you happy to see the outdoors (or windows to anywhere)
-    local count = room:countWindows()
-    if room.room_info.id == "staff_room" then -- Pleased another bit
-      count = count * 2
-    end
-    if count > 0 then
-      -- More windows help but in smaller increments
-      self:changeAttribute("happiness", math.round(math.log(count)) / 1000)
-    end
-
-    -- Extra space in the room you are in adds to your happiness
-    local extraspace = (room.width * room.height) / (room.room_info.minimum_size * room.room_info.minimum_size)
-    -- Greater space helps but in smaller increments
-    self:changeAttribute("happiness", math.round(math.log(extraspace)) / 1000)
+    self:changeAttribute("happiness", room.happiness_factor)
   end
 
   return true
@@ -141,7 +127,7 @@ function Staff:tick()
   end
 
   -- Make staff members request a raise if they are very unhappy
-  if not self.world.debug_disable_salary_raise and self.attributes["happiness"] < 0.1 then
+  if not self.world.debug_disable_salary_raise and self:getAttribute("happiness") < 0.1 then
     if not self.timer_until_raise then
       self.timer_until_raise = 200
     end
@@ -183,23 +169,22 @@ function Staff:checkIfWaitedTooLong()
           break
         end
       end
-      --If the hospital policy is set to automatically grant wage increases, grant the requested raise
-      --instead of firing the staff member
+      -- If the hospital policy is set to automatically grant wage increases, grant
+      -- the requested raise instead of firing the staff member
       if self.hospital.policies.grant_wage_increase then
         local amount = math.floor(math.max(self.profile.wage * 1.1, (self.profile:getFairWage(self.world) + self.profile.wage) / 2) - self.profile.wage)
         self.quitting_in = nil
-        self:setMood("pay_rise", "deactivate")
         self.hospital:removeMessage(self)
         self:increaseWage(amount)
         return
       end
 
-      -- Plays the sack sound, but maybe it's good that you hear a staff member leaving?
+      -- else: The staff member is sacked
       if staff_rise_window then
         staff_rise_window:fireStaff()
-      else
-        self:fire()
+        return
       end
+      self:fire()
     end
   end
 end
@@ -235,6 +220,11 @@ function Staff:isResting()
   end
 end
 
+--! Destroys any raise request window that may be queued
+function Staff:removeQueuedStaffMessage()
+  self.hospital:removeMessage(self)
+end
+
 -- Immediately terminate the staff member's employment.
 function Staff:fire()
   if self.fired then
@@ -246,6 +236,7 @@ function Staff:fire()
   if staff_window and staff_window.staff == self then
       staff_window:close()
   end
+  self:removeQueuedStaffMessage()
   self.hospital:spendMoney(self.profile.wage, _S.transactions.severance .. ": "
       .. self.profile:getFullName())
   self.world.ui:playSound("sack.wav")
@@ -267,6 +258,7 @@ function Staff:fire()
 end
 
 function Staff:die()
+  self:removeQueuedStaffMessage()
   -- Update the staff management screen (if present) accordingly
   local window = self.world.ui:getWindow(UIStaffManagement)
   if window then
@@ -333,9 +325,9 @@ end
 -- so amounts here should be appropriately small comma values.
 function Staff:tire(amount)
   -- The no rest cheat overrides tiring effects
-  if self.hospital.hosp_cheats:isCheatActive("no_rest_cheat") then return end
-
-  self:changeAttribute("fatigue", amount)
+  if not self.hospital.hosp_cheats:isCheatActive("no_rest_cheat") then
+    self:changeAttribute("fatigue", amount)
+  end
   self:updateDynamicInfo()
 end
 
@@ -359,10 +351,10 @@ function Staff:updateSpeed()
     level = 1
   elseif self.hospital and self.hospital.hosp_cheats:isCheatActive("no_rest_cheat") then
     level = 3 -- Cheat makes everyone speedy
-  elseif self.attributes["fatigue"] then
-    if self.attributes["fatigue"] >= 0.8 then
+  elseif self.humanoid_class ~= "Receptionist" then
+    if self:isCrackUpTired() then
       level = level - 2
-    elseif self.attributes["fatigue"] >= 0.7 then
+    elseif self:isVeryTired() then
       level = level - 1
     end
   end
@@ -382,12 +374,12 @@ end
 -- and go to the StaffRoom if it is.
 function Staff:checkIfNeedRest()
   -- Only when the staff member is very tired should the icon emerge. Unhappiness will also escalate
-  if self.attributes["fatigue"] >= 0.7 then
+  if self:isVeryTired() then
     self:setMood("tired", "activate")
     self:changeAttribute("happiness", -0.0002)
   end
   -- If above the policy threshold, go to the staff room.
-  if self.attributes["fatigue"] >= self.hospital.policies["goto_staffroom"] and
+  if self:getAttribute("fatigue") >= self.hospital.policies["goto_staffroom"] and
       not class.is(self:getRoom(), StaffRoom) then
     -- The staff will get unhappy if there is no staffroom to rest in.
     if self.waiting_for_staffroom then
@@ -470,7 +462,7 @@ end
 
 -- Helper function to decide if Staff fulfills a criterion
 -- (one of "Doctor", "Nurse", "Psychiatrist", "Surgeon", "Researcher" and "Handyman", "Receptionist", "Junior", "Consultant")
-function Staff:fulfillsCriterion(criterion) -- luacheck: ignore 212 keep args from parent class
+function Staff:fulfillsCriterion(criterion)
   return false
 end
 
@@ -559,9 +551,19 @@ end
 -- Makes the staff member request a raise of 10%, or a wage exactly in the middle of their current and a fair one, whichever is more.
 function Staff:requestRaise()
   assert(self.hospital, "A staff member asked for a pay rise who doesn't belong to a hospital!")
+  local max_salary = self.world.map.level_config.payroll.MaxSalary
+  -- Never request a raise if already at max salary
+  if self.profile.wage >= max_salary then
+    self.timer_until_raise = nil
+    return
+  end
   -- Check whether there is already a request for raise.
   if not self:isMoodActive("pay_rise") then
     local amount = math.floor(math.max(self.profile.wage * 1.1, (self.profile:getFairWage() + self.profile.wage) / 2) - self.profile.wage)
+    -- Don't ask over the salary cap
+    if self.profile.wage + amount > max_salary then
+      amount = max_salary - self.profile.wage
+    end
     -- At least for now, staff are timid, and only ask for raises 1/5th of the time
     if math.random(1, 5) ~= 1 or amount <= 0 then
       self.timer_until_raise = nil
@@ -578,16 +580,24 @@ end
 -- any request raise dialogs.
 --!param amount (integer) The amount, in game dollars per month, to increase
 -- the salary by.
+--!return (bool) Whether the wage actually increased
 function Staff:increaseWage(amount)
-  self.profile.wage = self.profile.wage + amount
-  self.world.ui:playSound("cashreg.wav")
-  if self.profile.wage > 2000 then -- What cap here?
-    self.profile.wage = 2000
-  else -- If the cap has been reached this member of staff won't get unhappy
-       -- ever again...
-    self:changeAttribute("happiness", 0.99)
-    self:setMood("pay_rise", "deactivate")
+  -- Are we already paid the maximum?
+  local max_salary = self.world.map.level_config.payroll.MaxSalary
+  local wage_raised = true
+  if self.profile.wage >= max_salary then
+    wage_raised = false -- Already at max salary
+  elseif self.profile.wage + amount > max_salary then
+    -- Maximum salary hit. The staff member will never be unhappy again
+    self.profile.wage = max_salary
+  else
+    -- Apply new salary
+    self.profile.wage = self.profile.wage + amount
   end
+  -- Reset
+  self:setMood("pay_rise", "deactivate")
+  self:changeAttribute("happiness", 0.99)
+  return wage_raised
 end
 
 --! Sets dynamic info text before the dynamic info update
@@ -601,15 +611,16 @@ end
 function Staff:updateDynamicInfo()
   local dynamic_text = self.dynamic_text or ""
   local fatigue_text = _S.dynamic_info.staff.tiredness
-  if not self.attributes["fatigue"] then
+  if self.humanoid_class == "Receptionist" then
     fatigue_text = nil
+  else
+    self:setDynamicInfo('progress', self:getAttribute("fatigue"))
   end
   self:setDynamicInfo('text', {
     self.profile.profession,
     dynamic_text,
     fatigue_text,
   })
-  self:setDynamicInfo('progress', self.attributes["fatigue"])
   if self.hospital then
     self:setDynamicInfo('dividers', {self.hospital.policies["goto_staffroom"]})
   end
@@ -643,11 +654,10 @@ function Staff:afterLoad(old, new)
     self.profile.world = self.world
   end
   if old < 68 and new >= 68 then
-    if self.attributes["fatigue"] then
-      if self.attributes["fatigue"] >= self.hospital.policies["goto_staffroom"] then
-        self:goToStaffRoom()
-        self.going_to_staffroom = true
-      end
+    if self.humanoid_class ~= "Receptionist" and
+        self:getAttribute("fatigue") >= self.hospital.policies["goto_staffroom"] then
+      self:goToStaffRoom()
+      self.going_to_staffroom = true
     end
   end
 
@@ -698,8 +708,8 @@ function Staff:getServiceQuality()
 
   local weighted_skill = skill_weight * self.profile.skill
   -- Less fatigue is better
-  local weighted_restfulness = restfulness_weight * (1 - self.attributes["fatigue"])
-  local weighted_happiness = happiness_weight * self.attributes["happiness"]
+  local weighted_restfulness = restfulness_weight * (1 - self:getAttribute("fatigue"))
+  local weighted_happiness = happiness_weight * self:getAttribute("happiness")
 
   return weighted_skill + weighted_restfulness + weighted_happiness
 end
@@ -711,5 +721,17 @@ function Staff:tostring()
   return Humanoid.tostring(self)
 end
 
+--! Judge tiredness based on the level config (which has a default of 700)
+--!return (boolean) Is staff member very tired?
+function Staff:isVeryTired()
+  return self:getAttribute("fatigue") * 1000 >= self.world.map.level_config.gbv.VeryTired
+end
+
+--! Judge crack up tiredness based on the level config (which has a default of 800)
+--!return (boolean) Is staff member very tired?
+function Staff:isCrackUpTired()
+  return self:getAttribute("fatigue") * 1000 >= self.world.map.level_config.gbv.CrackUpTired
+end
+
 -- Dummy callback for savegame compatibility
 local callbackNewRoom = --[[persistable:staff_build_staff_room_callback]] function() end
