@@ -42,16 +42,14 @@ function Doctor:tickDay()
 
   -- if you overwork your Dr's then there is a chance that they can go crazy
   -- when this happens, find him and get him to rest straight away
-  if self.attributes["fatigue"] then
-    if self.attributes["fatigue"] < 0.7 then
-      if self:isResting() then
-        self:setCrazy(false)
-      end
-    else
-      -- doctor can go crazy if they're too tired
-      if math.random(1, 300) == 1 then
-        self:setCrazy(true)
-      end
+  if not self:isVeryTired() then
+    if self:isResting() then
+      self:setCrazy(false)
+    end
+  else
+    -- doctor can go crazy if they're too tired
+    if math.random(1, 300) == 1 then
+      self:setCrazy(true)
     end
   end
 
@@ -140,7 +138,7 @@ function Doctor:setProfile(profile)
   self:updateStaffTitle()
 end
 
-function Doctor:updateSkill(consultant, trait, amount) -- luacheck: ignore 212
+function Doctor:updateSkill(consultant, trait, amount)
 -- consultant is kept for todo detailed in Doctor:trainSkill
   local old_profile = {
     is_junior = self.profile.is_junior,
@@ -155,7 +153,7 @@ function Doctor:updateSkill(consultant, trait, amount) -- luacheck: ignore 212
   self.profile[trait] = self.profile[trait] + amount
   if self.profile[trait] >= 1.0 then
     self.profile[trait] = 1.0
-    local is = trait:match"^is_(.*)"
+    local is = trait:match("^is_(.*)")
     if is == "surgeon" or is == "psychiatrist" or is == "researcher" then
       self.hospital:giveAdvice({ _A.information.promotion_to_specialist:format(_S.staff_title[is]) })
       -- patients might we waiting for a doctor with this skill, notify them
