@@ -72,7 +72,7 @@ function GameUI:GameUI(app, local_hospital, map_editor)
     -- For a standard 128x128 map, screen size would have to be in the
     -- region of 3276x2457 in order to be too large.
     if not self.map_editor then
-      error("Screen size too large for the map")
+      error("Screen size too large for the map. Adjust your resolution in Settings.")
     end
   end
   self.screen_offset_x, self.screen_offset_y = app.map:WorldToScreen(
@@ -476,6 +476,15 @@ function GameUI:onCursorWorldPositionChange()
   if not overwindow and wx > 0 and wy > 0 and wx < self.app.map.width and wy < self.app.map.height then
     room = self.app.world:getRoom(wx, wy)
   end
+  -- Find the room associated with the current entity (Usually only applies to doors)
+  if entity and not room then
+    if entity.room then
+      room = entity.room
+    elseif entity.object_type and entity.object_type.id == "swing_door_left" then
+      -- Special case to catch the non-dominant side of a double-door
+      room = entity.master.room
+    end
+  end
   if room ~= self.cursor_room then
     -- Unset queue mood for patients queueing the old room
     if self.cursor_room then
@@ -519,11 +528,13 @@ local UpdateCursorPosition = TH.cursor.setPosition
 
 local highlight_x, highlight_y
 
---! Called when the mouse enters or leaves the game window.
+--! Called when focus changes on game window.
+--!param gain (number) 1 for in-focus, 0 for out-of-focus
 function GameUI:onWindowActive(gain)
   if gain == 0 then
     self.tick_scroll_amount_mouse = false
   end
+  UI.onWindowActive(self, gain)
 end
 
 -- TODO: try to remove duplication with UI:onMouseMove
@@ -542,13 +553,22 @@ function GameUI:onMouseMove(x, y, dx, dy)
   if self:onCursorWorldPositionChange() or self.simulated_cursor then
     repaint = true
   end
-  if self.buttons_down.mouse_middle then
+
+  if self:_isMouseScrollButtonDown() then
     local zoom = self.zoom_factor
-    self.current_momentum.x = -dx/zoom
-    self.current_momentum.y = -dy/zoom
+    self.current_momentum.x = self.current_momentum.x - dx/zoom
+    self.current_momentum.y = self.current_momentum.y - dy/zoom
+
+    local momentum_x_int = math.round(self.current_momentum.x)
+    local momentum_y_int = math.round(self.current_momentum.y)
+
     -- Stop zooming when the middle mouse button is pressed
     self.current_momentum.z = 0
-    self:scrollMap(self.current_momentum.x, self.current_momentum.y)
+    self:scrollMap(momentum_x_int, momentum_y_int)
+
+    self.current_momentum.x = self.current_momentum.x - momentum_x_int
+    self.current_momentum.y = self.current_momentum.y - momentum_y_int
+
     repaint = true
   end
 
@@ -700,7 +720,7 @@ end
 --!param x (float) normalised x value of the gesture
 --!param y (float) normalised y value of the gesture
 --!return (boolean) event processed indicator
-function GameUI:onMultiGesture(numfingers, dTheta, dDist, x, y) -- luacheck: ignore 212 dTheta
+function GameUI:onMultiGesture(numfingers, dTheta, dDist, x, y)
   -- only deal with 2 finger events for now
   if numfingers == 2 then
     -- calculate magnitude of pinch
@@ -775,9 +795,21 @@ function GameUI:playAnnouncement(name, priority, played_callback, played_callbac
   self.announcer:playAnnouncement(name, priority, played_callback, played_callback_delay)
 end
 
+--! Check whether the configured mouse drag button is being held down (true) or not (false).
+-- fixme: right mouse scrolling currently breaks other mouse operations (see issue 2469).
+function GameUI:_isMouseScrollButtonDown()
+  local mouse_scroll_button_down
+  if self.app.config.right_mouse_scrolling then
+    mouse_scroll_button_down = self.buttons_down.mouse_right
+  else
+    mouse_scroll_button_down = self.buttons_down.mouse_middle
+  end
+  return mouse_scroll_button_down
+end
+
 function GameUI:onTick()
   local repaint = UI.onTick(self)
-  if not self.buttons_down.mouse_middle then
+  if not self:_isMouseScrollButtonDown() then
     if math.abs(self.current_momentum.x) < 0.2 and math.abs(self.current_momentum.y) < 0.2 then
       -- Stop scrolling
       self.current_momentum.x = 0.0
@@ -813,7 +845,7 @@ function GameUI:onTick()
       -- If the middle mouse button is down, then the world is being dragged,
       -- and so the scroll direction due to the cursor being at the map edge
       -- should be opposite to normal to make it feel more natural.
-      if self.buttons_down.mouse_middle then
+      if self:_isMouseScrollButtonDown() then
         dx, dy = -dx, -dy
       end
     end
@@ -1085,13 +1117,14 @@ tutorial_phases = {
         -- the real game uses three.
         local texts = TheApp.using_demo_files and {
           {_S.introduction_texts["level15"]},
-          {_S.introduction_texts["demo"]},
         } or {
           {_S.introduction_texts["level15"]},
           {_S.introduction_texts["level16"]},
           {_S.introduction_texts["level17"]},
-          {_S.introduction_texts["level1"]},
         }
+        if TheApp.world.map.level_number ~= 1 then
+          table.insert(texts, _S.introduction_texts["level1"])
+        end
         TheApp.ui:addWindow(UIInformation(TheApp.ui, texts))
         TheApp.ui:addWindow(UIWatch(TheApp.ui, "initial_opening"))
       end,
@@ -1268,8 +1301,10 @@ end
 
 --! Offers a confirmation window to quit the game and return to main menu
 -- NB: overrides UI.quit, do NOT call it from here
-function GameUI:quit()
-  self:addWindow(UIConfirmDialog(self, false, _S.confirmation.quit, --[[persistable:gameui_confirm_quit]] function()
+--!param mapeditor (boolean) If the user is quitting the map editor
+function GameUI:quit(mapeditor)
+  local msg = mapeditor and _S.confirmation.quit_mapeditor or _S.confirmation.quit
+  self:addWindow(UIConfirmDialog(self, false, msg, --[[persistable:gameui_confirm_quit]] function()
     self.app:loadMainMenu()
   end))
 end
@@ -1281,3 +1316,8 @@ end
 function GameUI:showMenuBar()
   self.menu_bar:appear()
 end
+
+function GameUI:restartMapEditor()
+  self:addWindow(UIConfirmDialog(self, false, _S.confirmation.restart_mapeditor,
+    --[[persistable:app_hotkey_confirm_mapeditor_restart]] function() self.app:mapEdit() end))
+end
