@@ -79,7 +79,7 @@ pay_rise.regular[1] = "I'm totally frazzled. I need a good rest, plus a rise of
 
 -- Level description overrides where there are typos. Note: This is the only portion of the game that SHOULD use double space after fullstops etc.
 introduction_texts.level17 = " Last word of warning - keep a keen eye on your Reputation - this is what will attract the patients from far and wide to your establishment.  If you don't kill too many people and keep them reasonably happy you shouldn't have too much trouble on this level!// You're on you own now.  Good luck and all that."
-introduction_texts.level11 = " You've been given the chance to build the ultimate in hospitals.  This is an exceedingly prestigious area, and the Ministry would like to see the best possible hospital.  We'll be expecting you to make big money, have a superbly high reputation and cover every possible eventuality.  It's an important job, this.  You'll have to be something special to pull it off.  Note, too, that there have sightings of UFOs in the area.  Make sure your staff are prepared for some unexpected visitors.  Your hospital will need to be worth $240,000, you'll need $500,000 in the bank, and your reputation will need to be 700."
+introduction_texts.level11 = " You've been given the chance to build the ultimate in hospitals.  This is an exceedingly prestigious area, and the Ministry would like to see the best possible hospital.  We'll be expecting you to make big money, have a superbly high reputation and cover every possible eventuality.  It's an important job, this.  You'll have to be something special to pull it off.  Note, too, that there have been sightings of UFOs in the area.  Make sure your staff are prepared for some unexpected visitors.  Your hospital will need to be worth $240,000, you'll need $500,000 in the bank, and your reputation will need to be 700."
 introduction_texts.level9 = " Having filled the Ministry's bank account and paid for a new limousine for the Minister himself, you can now get back to creating a caring, well-run hospital for the benefit of the unwell and needy.  You can expect a lot of different problems to crop up here.  If you have enough well-trained staff and rooms, you should have all the angles covered.  Your hospital will need to be worth $200,000, and you'll need $400,000 in the bank.  Any less and you won't be able to finish the level."
 introduction_texts.level16 = " Once you have diagnosed some of the patients you will need to build treatment facilities and clinics to cure them - a good one to start off with is the Pharmacy.  You'll also need a Nurse to dispense the various drugs in the Pharmacy."
 introduction_texts.level10 = " As well as covering all the illnesses which crop up in this neck of the woods, the Ministry request that you spend some time concentrating on the efficiency of your drugs.  There have been some complaints from Ofsick, the Health Watchdog, so in order to look good you must make sure all your drugs are extremely efficient.  Also, make sure your hospital is above reproach as well. Keep those deaths down.  As a hint, you might like to keep space free for a Jelly Vat.  Develop all your drugs to at least 80 per cent efficiency, get a reputation of 650 and stash $500,000 in the bank to win."
@@ -193,6 +193,7 @@ menu_debug = {
   limit_camera                = "  LIMIT CAMERA  ",
   disable_salary_raise        = "  DISABLE SALARY RAISE  ",
   allow_blocking_off_areas    = "  ALLOW BLOCKING OFF AREAS  ",
+  allow_falling               = "  ALLOW FALLING  ",
   make_debug_fax              = "  MAKE DEBUG FAX  ",
   make_debug_patient          = "  MAKE DEBUG PATIENT  ",
   cheats                      = "  (%1%) CHEATS  ",
@@ -219,10 +220,10 @@ menu_debug_overlay = {
   parcel                      = "  PARCEL  ",
 }
 menu_player_count = {
-	players_1 = "  1 PLAYER  ",
-	players_2 = "  2 PLAYERS  ",
-	players_3 = "  3 PLAYERS  ",
-	players_4 = "  4 PLAYERS  ",
+  players_1 = "  1 PLAYER  ",
+  players_2 = "  2 PLAYERS  ",
+  players_3 = "  3 PLAYERS  ",
+  players_4 = "  4 PLAYERS  ",
 }
 adviser = {
   room_forbidden_non_reachable_parts = "Placing the room in this location would result in parts of the hospital not being reachable.",
@@ -238,6 +239,7 @@ adviser = {
     another_desk = "You'll need to build another desk for that new receptionist.",
     cannot_afford = "You don't have enough money in the bank to hire that person!", -- I can't see anything like this in the original strings
     cannot_afford_2 = "You don't have enough money in the bank to make that purchase!",
+    cannot_afford_machine = "You need at least $%1% in the bank to afford a new %2%!",
     falling_1 = "Hey! That is not funny, watch where you click that mouse; someone could get hurt!",
     falling_2 = "Stop messing about, how would you like it?",
     falling_3 = "Ouch, that had to hurt, someone call a Doctor!",
@@ -264,7 +266,7 @@ adviser = {
     norest_off_cheat = "Phew! Looks like that buzz finally wore off. Your staff will now rest properly.",
   },
   staff_place_advice = {
-    not_enough_lecture_chairs = "Each student doctor needs a lecture chair to sit in!"
+    not_enough_lecture_chairs = "Each student doctor needs a lecture chair to sit in!",
   },
 }
 
@@ -315,9 +317,18 @@ install = {
   cancel = "Cancel",
 }
 
-misc.not_yet_implemented = "(not yet implemented)"
-misc.no_heliport = "Either no diseases have been discovered yet, or there is no heliport on this map. It might be that you need to build a reception desk and hire a receptionist"
-misc.cant_treat_emergency = "Your hospital cannot treat this emergency because its disease has not been discovered. Feel free to try again."
+misc = {
+  not_yet_implemented = "(not yet implemented)",
+  no_heliport = "Either no diseases have been discovered yet, or there is no heliport on this map. It might be that you need to build a reception desk and hire a receptionist",
+  cant_treat_emergency = "Your hospital cannot treat this emergency because its disease has not been discovered. Feel free to try again.",
+  epidemics_off = "Epidemics are disabled",
+  epidemics_on = "Epidemics are re-enabled",
+  earthquakes_off = "Earthquakes are disabled",
+  earthquakes_on = "Earthquakes are re-enabled",
+  epidemic_no_icon_to_toggle = "Unable to show/hide infected icons - no epidemics in progress that are not revealed",
+  epidemic_no_diseases = "Cannot create epidemic - no contagious diseases available",
+  epidemic_no_receptionist = "Cannot create epidemic - no staffed reception desk",
+}
 
 main_menu = {
   new_game = "Campaign",
@@ -328,6 +339,7 @@ main_menu = {
   options = "Settings",
   map_edit = "Map Editor",
   savegame_version = "Savegame version: ",
+  updates_off = "Not checking for updates",
   version = "Version: ",
   exit = "Exit",
 }
@@ -346,6 +358,7 @@ tooltip.main_menu = {
 
 load_game_window = {
   caption = "Load Game (%1%)",
+  load_button = "Load",
 }
 
 tooltip.load_game_window = {
@@ -379,6 +392,8 @@ tooltip.custom_campaign_window = {
 save_game_window = {
   caption = "Save Game (%1%)",
   new_save_game = "New Savegame",
+  save_button = "Save",
+  missing_filename = "Please enter the name of the new save or select the save to overwrite.",
 }
 
 tooltip.save_game_window = {
@@ -389,6 +404,8 @@ tooltip.save_game_window = {
 save_map_window = {
   caption = "Save Map (%1%)",
   new_map = "New Map",
+  save_button = "Save",
+  missing_filename = "Please enter the name of the new map file or select the map file to overwrite.",
 }
 
 tooltip.save_map_window = {
@@ -396,15 +413,22 @@ tooltip.save_map_window = {
   new_map = "Enter name for a map savegame",
 }
 
+load_map_window = {
+  caption = "Load Map (%1%)",
+  load_button = "Load",
+}
+
 menu_list_window = {
   name = "Name",
   save_date = "Modified",
+  ok = "OK",
   back = "Back",
 }
 
 tooltip.menu_list_window = {
   name = "Click here to sort the list by name",
   save_date = "Click here to sort the list by last modification date",
+  ok = "Confirm choice",
   back = "Close this window",
 }
 
@@ -412,9 +436,14 @@ options_window = {
   caption = "Settings",
   option_on = "On",
   option_off = "Off",
+  option_enabled = "Enabled",
+  option_disabled = "Disabled",
   fullscreen = "Fullscreen",
   resolution = "Resolution",
   capture_mouse = "Capture Mouse",
+  right_mouse_scrolling = "Mouse Scrolling",
+  right_mouse_scrolling_option_middle = "Middle Button",
+  right_mouse_scrolling_option_right = "Right Button",
   custom_resolution = "Custom...",
   width = "Width",
   height = "Height",
@@ -429,6 +458,8 @@ options_window = {
   shift_scrollspeed = "Shift Scroll Speed",
   zoom_speed = "Zoom Speed",
   hotkey = "Hotkeys",
+  check_for_updates = "Check for Updates",
+  jukebox = "Jukebox",
 }
 
 tooltip.options_window = {
@@ -437,6 +468,7 @@ tooltip.options_window = {
   resolution = "The resolution the game should run in",
   select_resolution = "Select a new resolution",
   capture_mouse = "Click to toggle capturing the cursor in the game window",
+  right_mouse_scrolling = "Toggle the mouse button that is used to scroll the map",
   width = "Enter desired screen width",
   height = "Enter desired screen height",
   apply = "Apply the entered resolution",
@@ -448,6 +480,7 @@ tooltip.options_window = {
   language = "The language texts in the game will appear in",
   select_language = "Select the game language",
   language_dropdown_item = "Choose %s as language",
+  language_dropdown_no_font = "Select a font in the folders settings to enable this language",
   back = "Close the Settings window",
   scrollspeed = "Set the scroll speed between 1 (slowest) to 10 (fastest). The default is 2.",
   shift_scrollspeed = "Set the speed of scrolling while the shift key is pressed. 1 (slowest) to 10 (fastest). The default is 4.",
@@ -459,6 +492,8 @@ tooltip.options_window = {
   apply_zoomspeed = "Apply the entered zoom speed.",
   cancel_zoomspeed = "Return without changing the zoom speed.",
   hotkey = "Change keyboard hotkeys.",
+  check_for_updates = "Sets whether the game should look for updates on launch.",
+  jukebox = "Open the Jukebox to control the music"
 }
 
 customise_window = {
@@ -519,7 +554,6 @@ tooltip.folders_window = {
   not_specified = "No folder location specified yet!",
   default = "Default location",
   reset_to_default = "Reset the directory to its default location",
- -- original_path = "The currently chosen directory of the original Theme Hospital installation", -- where is this used, I have left if for the time being?
   back  = "Close this menu and go back to the Settings Menu",
 }
 
@@ -696,6 +730,8 @@ errors = {
   dialog_missing_graphics = "Sorry, the demo data files don't contain this dialog.",
   save_prefix = "Error while saving game: ",
   load_prefix = "Error while loading game: ",
+  load_map_prefix = "Error while loading map: ",
+  load_level_prefix = "Error while loading level: ",
   no_games_to_contine = "There are no saved games.",
   load_quick_save = "Error, cannot load the quicksave as it does not exist, not to worry as we have now created one for you!",
   map_file_missing = "Could not find the map file %s for this level!",
@@ -712,6 +748,7 @@ errors = {
     demo_in_full = "Sorry, you can't open a demo savegame with the full game files loaded. Please update your TH Data folder setting.",
     full_in_demo = "Sorry, you can't open a full game save with the demo files loaded. Please update your TH Data folder setting.",
   },
+  music = "There are playback issues with one or more files in your music directory. Problematic files will be disabled in the jukebox. See the console window for more information.",
 }
 
 warnings = {
@@ -726,6 +763,8 @@ confirmation = {
   maximum_screen_size = "The screen size you have entered is greater than 3000 x 2000. Larger resolutions are possible but will require better hardware in order to maintain a playable frame rate. Are you sure you want to continue?",
   remove_destroyed_room = "Would you like to remove the room for $%d?",
   replace_machine_extra_info = "The new machine will have %d strength (currently %d).",
+  restart_mapeditor = "Are you sure you want to restart the map editor?",
+  quit_mapeditor = "Are you sure you want to quit the map editor?",
 }
 
 information = {
@@ -759,7 +798,7 @@ totd_window = {
     "Did you try to enter the European emergency number (112) into the fax machine? Make sure your sound is on!",
     "You can adjust some settings such as the resolution and language in the options window found both in the main menu and ingame.",
     "You selected a language other than English, but there's English text all over the place? Help us by translating missing texts into your language!",
-    "The CorsixTH team is looking for reinforcements! Are you interested in coding, translating or creating graphics for CorsixTH? Contact us at our Forum, Mailing List or IRC Channel (corsix-th at freenode).",
+    "The CorsixTH team is looking for reinforcements! Are you interested in coding, translating or creating graphics for CorsixTH? Contact us at our Discord Server, Sub-Reddit or Matrix Server. Links are on our website (CorsixTH.com).",
     "If you find a bug, please report it at our bugtracker: th-issues.corsix.org",
     "Each level has certain requirements to fulfill before you can move on to the next one. Check the status window to see your progression towards the level goals.",
     "If you want to edit or remove an existing room, you can do so with the edit room button found in the bottom toolbar.",
@@ -784,6 +823,10 @@ debug_patient_window = {
   caption = "Debug Patient",
 }
 
+tooltip.debug_patient_window = {
+  item = "Create a debug patient with %s",
+}
+
 cheats_window = {
   caption = "Cheats",
   warning = "Warning: You will not get any bonus points at the end of the level if you cheat!",
@@ -796,9 +839,11 @@ cheats_window = {
     all_research = "All Research Cheat",
     emergency = "Create Emergency",
     vip = "Create VIP",
+    toggle_earthquake = "Toggle earthquakes",
     earthquake = "Create Earthquake",
+    toggle_epidemic = "Toggle epidemics",
     epidemic = "Spawn contagious patient",
-    toggle_infected = "Toggle infected icons",
+    show_infected = "Show or hide infected icons",
     create_patient = "Create Patient",
     end_month = "End of Month",
     end_year = "End of Year",
@@ -806,6 +851,8 @@ cheats_window = {
     win_level = "Win Level",
     increase_prices = "Increase prices",
     decrease_prices = "Decrease prices",
+    reset_death_count = "Reset death count",
+    max_reputation = "Max reputation",
   },
   close = "Close",
 }
@@ -817,9 +864,11 @@ tooltip.cheats_window = {
     all_research = "Completes all research",
     emergency = "Creates an emergency",
     vip = "Creates a VIP",
+    toggle_earthquake = "Toggle earthquakes",
     earthquake = "Creates an earthquake",
+    toggle_epidemic = "Toggle whether epidemics can happen",
     epidemic = "Creates a contagious patient who may cause an epidemic to happen",
-    toggle_infected = "Toggle the infected icons for the active, discovered epidemic",
+    show_infected = "Show/hide the infected icons for the active, discovered epidemic",
     create_patient = "Creates a Patient at the map border",
     end_month = "Jumps to the end of the month",
     end_year = "Jumps to the end of the year",
@@ -827,6 +876,8 @@ tooltip.cheats_window = {
     win_level = "Win the current level",
     increase_prices = "Increase all prices by 50% (max. 200%)",
     decrease_prices = "Decrease all prices by 50% (min. 50%)",
+    reset_death_count = "Reset the hospital death count to zero",
+    max_reputation = "Set the hospital reputation to the maximum",
   }
 }
 
@@ -880,17 +931,10 @@ map_editor_window = {
     north_wall = "North wall",
     west_wall = "West wall",
     helipad = "Helipad",
+    set_parcel = "Set parcel num",
     delete_wall = "Delete walls",
-    parcel_0 = "Parcel 0",
-    parcel_1 = "Parcel 1",
-    parcel_2 = "Parcel 2",
-    parcel_3 = "Parcel 3",
-    parcel_4 = "Parcel 4",
-    parcel_5 = "Parcel 5",
-    parcel_6 = "Parcel 6",
-    parcel_7 = "Parcel 7",
-    parcel_8 = "Parcel 8",
-    parcel_9 = "Parcel 9",
+    parcel = "Parcel %d",
+    set_parcel_tooltip = "Choose a number and press enter.",
     camera_1 = "Camera 1",
     camera_2 = "Camera 2",
     camera_3 = "Camera 3",
@@ -900,7 +944,10 @@ map_editor_window = {
     heliport_3 = "Heliport 3",
     heliport_4 = "Heliport 4",
     paste = "Paste area",
-  }
+  },
+  checks = {
+    spawn_points_and_path = "Warning: Patients cannot reach the hospital. They need 'road' tiles or 'outside' grey tiles at the edge of the map and a path of these tiles to the hospital entrance.",
+  },
 }
 
 hotkeys_file_err = {
@@ -917,55 +964,9 @@ transactions.remove_room = "Build: Remove destroyed room"
 options_window.change_resolution = "Change resolution"
 tooltip.options_window.change_resolution = "Change the window resolution to the dimensions entered on the left"
 
---[[ Compatibility mapping for VIP result faxes in old saves (< 0.66). Using non-
-standard string formatting here, which should not be repeated in normal
-circumstances. This mapping will cause the legacy string to print in English but only
-for the relevant fax. These should be deleted on 2024 release. ]]--
-fax = {
-  vip_visit_result = {
-    ordered_remarks = {
-      [1] = fax.vip_visit_result.remarks[1],
-      [2] = fax.vip_visit_result.remarks[2],
-      [3] = fax.vip_visit_result.remarks[3],
-      [4] = fax.vip_visit_result.remarks[4],
-      [5] = fax.vip_visit_result.remarks[5],
-      [6] = fax.vip_visit_result.remarks[6],
-      [7] = fax.vip_visit_result.remarks[7],
-      [8] = fax.vip_visit_result.remarks[8],
-      [9] = fax.vip_visit_result.remarks[9],
-      [10] = fax.vip_visit_result.remarks[10],
-      [11] = fax.vip_visit_result.remarks[11],
-      [12] = fax.vip_visit_result.remarks[12],
-      [13] = fax.vip_visit_result.remarks[13],
-      [14] = fax.vip_visit_result.remarks[14],
-      [15] = fax.vip_visit_result.remarks[15],
-    },
-    remarks = {
-      super = {
-        fax.vip_visit_result.remarks[1],
-        fax.vip_visit_result.remarks[2],
-        fax.vip_visit_result.remarks[3],
-      },
-      good = {
-        fax.vip_visit_result.remarks[4],
-        fax.vip_visit_result.remarks[5],
-        fax.vip_visit_result.remarks[6],
-      },
-      mediocre = {
-        fax.vip_visit_result.remarks[7],
-        fax.vip_visit_result.remarks[8],
-        fax.vip_visit_result.remarks[9],
-      },
-      bad = {
-        fax.vip_visit_result.remarks[10],
-        fax.vip_visit_result.remarks[11],
-        fax.vip_visit_result.remarks[12],
-      },
-      very_bad = {
-        fax.vip_visit_result.remarks[13],
-        fax.vip_visit_result.remarks[14],
-        fax.vip_visit_result.remarks[15],
-      }
-    }
-  }
+cheats_window.cheats = {
+ toggle_infected = show_infected,
+}
+tooltip.cheats_window.cheats = {
+ toggle_infected = show_infected,
 }
