@@ -493,18 +493,47 @@ function Room:commandEnteringStaff(humanoid, already_initialized)
   end
 end
 
+--! Activates and deactivates the staff waiting for patient mood icon
+-- and dynamic info text
+--!param activate (bool) - true to activate, false or nil to deactivate
+function Room:_staffWaitToggle(activate)
+  if not self.staff_member and not self.staff_member_set then
+    return -- No staff in room
+  end
+
+  local state = "deactivate"
+  local dynamic_text = ""
+
+  if activate then
+    dynamic_text = _S.dynamic_info.staff.actions.waiting_for_patient
+    state = "activate"
+  end
+
+  if not self.staff_member_set and self.staff_member then
+    self.staff_member:setMood("staff_wait", state)
+    self.staff_member:setDynamicInfoText(dynamic_text)
+  else
+    for staff_member in pairs(self.staff_member_set) do
+      staff_member:setMood("staff_wait", state)
+      staff_member:setDynamicInfoText(dynamic_text)
+    end
+  end
+end
+
+--! Check the target room for a staff wait toggle is not staff room/training/toilets,
+--! and the front humanoid is a patient.
+function Room:_checkWaitToggleValidTarget()
+  return self:hasQueueDialog() and self.room_info.id ~= "toilets" and
+      class.is(self.door.queue:front(), Patient)
+end
+
 function Room:commandEnteringPatient(humanoid)
   -- To be extended in derived classes
   self.door.queue.visitor_count = self.door.queue.visitor_count + 1
   humanoid:updateDynamicInfo("")
 
-  for room_humanoid in pairs(self.humanoids) do -- Staff is no longer waiting
-    if class.is(room_humanoid, Staff) then
-      if room_humanoid.humanoid_class ~= "Handyman" then
-        room_humanoid:setMood("staff_wait", "deactivate")
-        room_humanoid:setDynamicInfoText("")
-      end
-    end
+  if self:_checkWaitToggleValidTarget() then
+    self:_staffWaitToggle(false) -- Staff no longer waiting
   end
 end
 
@@ -516,16 +545,8 @@ function Room:tryAdvanceQueue()
     if self:canHumanoidEnter(front) then
       self.door.queue:pop()
       self.door:updateDynamicInfo()
-      -- Do nothing if it is the staff room or training room.
-      if self:hasQueueDialog() then
-        for room_humanoid in pairs(self.humanoids) do -- Staff is now waiting
-          if class.is(room_humanoid, Staff) then
-            if room_humanoid.humanoid_class ~= "Handyman" then
-              room_humanoid:setMood("staff_wait", "activate")
-              room_humanoid:setDynamicInfoText(_S.dynamic_info.staff.actions.waiting_for_patient)
-            end
-          end
-        end
+      if self:_checkWaitToggleValidTarget() then
+        self:_staffWaitToggle(true) -- Staff are now waiting
       end
     elseif self.humanoids[front] then
       self.door.queue:pop()
@@ -534,6 +555,8 @@ function Room:tryAdvanceQueue()
   end
 end
 
+--! Handles the departure of a humanoid from the room
+--!param humanoid The subject entity
 function Room:onHumanoidLeave(humanoid)
   if self.staff_member == humanoid then
     self.staff_member = nil
@@ -544,7 +567,7 @@ function Room:onHumanoidLeave(humanoid)
     return
   end
   self.humanoids[humanoid] = nil
-  local staff_leaving = false
+  local staff_leaving = false -- used only for staff leaving immediately after a patient
 
   if class.is(humanoid, Patient) then
     -- Some staff member in the room might be waiting to get to the staffroom.
@@ -685,6 +708,7 @@ function Room:roomFinished()
     self.world.dispatcher:callForStaff(self)
   end
   self:tryAdvanceQueue()
+  self:calculateHappinessFactor()
 end
 
 --! Try to move a patient from the old room to the new room.
@@ -977,10 +1001,10 @@ end
 
 --! Stub to be extended in subclasses, if needed.
 function Room:afterLoad(old, new)
-  if old and old < 46 then
+  if old < 46 then
     self.humanoids_enroute = {--[[a set rather than a list]]}
   end
-  if old and old < 137 then
+  if old < 137 then
     if self.door.queue then
       -- reset expected count so we can recalculate it
       self.door.queue.expected = {}
@@ -1005,6 +1029,9 @@ function Room:afterLoad(old, new)
     -- no longer using this so empty it
     self.humanoids_enroute = {}
   end
+  if old < 186 then
+    self:calculateHappinessFactor()
+  end
 end
 
 --[[ Is the room one of the diagnosis rooms for the patient?
@@ -1048,11 +1075,10 @@ function Room:getStaffServiceQuality()
   return quality
 end
 
+local window_tile = list_to_set({116, 117, 118, 119, 124, 125, 126, 127})
 --! Count the number of windows in the room
 --!return (int) Number of windows
 function Room:countWindows()
-  local window_tile = {[116]=true, [117]=true, [118]=true, [119]=true,
-   [124]=true, [125]=true, [126]=true, [127]=true}
   local map, count = self.world.ui.app.map.th, 0
   for x = self.x, self.x + self.width do
     for y = self.y, self.y + self.height do
@@ -1080,3 +1106,26 @@ function Room:calculateRemovalCost()
   end
   return cost
 end
+
+--! Calculate the effect the room has on humanoid happiness
+function Room:calculateHappinessFactor()
+  -- The number of windows affects happiness
+  local window_factor, space_factor, window_count = 0, 0, self:countWindows()
+  if window_count > 0 then
+    if self.room_info.id == "staff_room" then
+      -- Staff are pleased to rest in a staff room with windows
+      window_count = window_count * 2
+    end
+    -- More windows help but in smaller increments
+   window_factor = math.round(math.log(window_count)) / 1000
+  end
+
+  -- Extra space in the room affects happiness
+  local extraspace = (self.width * self.height) / (self.room_info.minimum_size * self.room_info.minimum_size)
+  if extraspace > 1 then
+    -- Greater space helps but in smaller increments
+    space_factor = math.round(math.log(extraspace)) / 1000
+  end
+
+  self.happiness_factor = window_factor + space_factor
+end
