@@ -43,7 +43,7 @@ SOFTWARE.
 #if SDL_VERSION_ATLEAST(2, 0, 10)
 
 //! How much to overdraw scaled sprites to ensure no gaps are visible.
-const float frect_overdraw = 0.002f;
+const float frect_overdraw = 0.01f;
 
 #define SDL_FRECT_UNIT float
 #else
@@ -183,8 +183,8 @@ void getScaleRect(const SDL_Rect* rect, double scale_factor,
   // on scaled rendering.
   dst_rect->x = static_cast<float>(rect->x * scale_factor) - frect_overdraw;
   dst_rect->y = static_cast<float>(rect->y * scale_factor) - frect_overdraw;
-  dst_rect->w = static_cast<float>(rect->w * scale_factor) + frect_overdraw;
-  dst_rect->h = static_cast<float>(rect->h * scale_factor) + frect_overdraw;
+  dst_rect->w = static_cast<float>(rect->w * scale_factor) + 2 * frect_overdraw;
+  dst_rect->h = static_cast<float>(rect->h * scale_factor) + 2 * frect_overdraw;
 #else
   // Prior to SDL 2.0.10, fallback to using the enclosing integer SDL_Rect for
   // scaled rendering.
@@ -420,7 +420,7 @@ class render_target::scoped_target_texture
     } else {
       target->draw(texture, nullptr, &rect, 0);
     }
-    SDL_DestroyTexture(texture);
+    target->intermediate_textures.push_back(texture);
   }
 
  private:
@@ -474,6 +474,7 @@ bool render_target::create(const render_target_creation_params* pParams) {
   apply_opengl_clip_fix = std::strncmp(info.name, "opengl", 6) == 0 &&
                           sdlVersion.major == 2 && sdlVersion.minor == 0 &&
                           sdlVersion.patch < 4;
+  SDL_SetWindowMinimumSize(window, 640, 480);
 
   return update(pParams);
 }
@@ -508,6 +509,7 @@ bool render_target::update(const render_target_creation_params* pParams) {
 
 void render_target::destroy() {
   zoom_buffer.reset();
+  destroy_intermediate_textures();
 
   if (pixel_format) {
     SDL_FreeFormat(pixel_format);
@@ -587,6 +589,9 @@ const char* render_target::get_renderer_details() const {
 const char* render_target::get_last_error() { return SDL_GetError(); }
 
 bool render_target::start_frame() {
+  // Destroy any intermediate texures used last frame.
+  destroy_intermediate_textures();
+
   fill_black();
   return true;
 }
@@ -895,6 +900,13 @@ double render_target::draw_scale() const {
   return global_scale_factor;
 }
 
+void render_target::destroy_intermediate_textures() {
+  for (SDL_Texture* texture : intermediate_textures) {
+    SDL_DestroyTexture(texture);
+  }
+  intermediate_textures.clear();
+}
+
 raw_bitmap::raw_bitmap() {
   texture = nullptr;
   bitmap_palette = nullptr;
