@@ -33,6 +33,10 @@ SOFTWARE.
 #ifdef CORSIX_TH_USE_SDL_MIXER
 #include <SDL_mixer.h>
 #endif
+#ifdef WITH_UPDATE_CHECK
+#include <curl/curl.h>
+#endif
+
 // Template magic for checking type equality
 template <typename T1, typename T2>
 struct types_equal {
@@ -49,12 +53,12 @@ struct types_equal<T1, T1> {
 };
 
 static void cleanup(lua_State* L) {
+  lua_close(L);
 #ifdef CORSIX_TH_USE_SDL_MIXER
   while (Mix_QuerySpec(nullptr, nullptr, nullptr)) {
     Mix_CloseAudio();
   }
 #endif
-  lua_close(L);
   SDL_Quit();
 }
 
@@ -75,6 +79,10 @@ int main(int argc, char** argv) {
     int number_is_double[types_equal<lua_Number, double>::result];
   };
 
+#ifdef WITH_UPDATE_CHECK
+  curl_global_init(CURL_GLOBAL_DEFAULT);
+#endif
+
   bool bRun = true;
 
   while (bRun) {
@@ -124,5 +132,8 @@ int main(int argc, char** argv) {
       std::printf("\n\nRestarting...\n\n\n");
     }
   }
+#ifdef WITH_UPDATE_CHECK
+  curl_global_cleanup();
+#endif
   return 0;
 }
